pub struct BrowseFilter { /* private fields */ }Expand description
Simple filter for the Browser. All discovered nodes will be recursively browsed using the stored configuration.
Implementations
Sourceimpl BrowseFilter
impl BrowseFilter
Sourcepub fn new(
direction: BrowseDirection,
reference_type_id: impl Into<NodeId>,
include_subtypes: bool,
) -> BrowseFilter
pub fn new( direction: BrowseDirection, reference_type_id: impl Into<NodeId>, include_subtypes: bool, ) -> BrowseFilter
Create a new browse filter for browsing references of
reference_type_id (optionally including subtypes) in the
given direction.
Sourcepub fn new_description_from_node(&self, node_id: NodeId) -> BrowseDescription
pub fn new_description_from_node(&self, node_id: NodeId) -> BrowseDescription
Create a new browse description from this filter and a node ID to browse.
Sourcepub fn new_hierarchical() -> BrowseFilter
pub fn new_hierarchical() -> BrowseFilter
Create a new browse filter for browsing hierarchical references.
Sourcepub fn node_class_mask(self, mask: NodeClassMask) -> BrowseFilter
pub fn node_class_mask(self, mask: NodeClassMask) -> BrowseFilter
Set the node class mask, the filter for allowed node classes
in the returned references. Defaults to all.
Sourcepub fn result_mask(self, mask: BrowseResultMaskFlags) -> BrowseFilter
pub fn result_mask(self, mask: BrowseResultMaskFlags) -> BrowseFilter
Set the result mask, indicating which values should be returned
for each reference. Defaults to all.
Sourcepub fn max_depth(self, depth: usize) -> BrowseFilter
pub fn max_depth(self, depth: usize) -> BrowseFilter
Set the maximum browse depth. If this is 1 only the root nodes will be browsed, if it is 0, there is no upper limit.