pub struct CreateSession<'a> { /* private fields */ }Expand description
Sends a CreateSessionRequest to the server, returning the session id of the created
session. Internally, the session will store the authentication token which is used for requests
subsequent to this call.
See OPC UA Part 4 - Services 5.6.2 for complete description of the service and error responses.
Note that in order to use the session you will need to store the auth token and use that in subsequent requests.
Note: Avoid calling this on sessions managed by the Session type. Session creation
is handled automatically as part of connect/reconnect logic.
Implementations
Sourceimpl<'a> CreateSession<'a>
impl<'a> CreateSession<'a>
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> CreateSession<'a>
pub fn diagnostics(self, bits: DiagnosticBits) -> CreateSession<'a>
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> CreateSession<'a>
pub fn timeout(self, timeout: Duration) -> CreateSession<'a>
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> CreateSession<'a>
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> CreateSession<'a>
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl<'a> CreateSession<'a>
impl<'a> CreateSession<'a>
Sourcepub fn new_manual(
certificate_store: &'a RwLock<RawRwLock, CertificateStore>,
endpoint: &'a EndpointDescription,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: u32,
) -> CreateSession<'a>
pub fn new_manual( certificate_store: &'a RwLock<RawRwLock, CertificateStore>, endpoint: &'a EndpointDescription, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: u32, ) -> CreateSession<'a>
Create a new CreateSession request with the given data.
Sourcepub fn client_description(
self,
desc: impl Into<ApplicationDescription>,
) -> CreateSession<'a>
pub fn client_description( self, desc: impl Into<ApplicationDescription>, ) -> CreateSession<'a>
Set the client description.
Sourcepub fn server_uri(self, server_uri: impl Into<UAString>) -> CreateSession<'a>
pub fn server_uri(self, server_uri: impl Into<UAString>) -> CreateSession<'a>
Set the server URI.
Sourcepub fn endpoint_url(
self,
endpoint_url: impl Into<UAString>,
) -> CreateSession<'a>
pub fn endpoint_url( self, endpoint_url: impl Into<UAString>, ) -> CreateSession<'a>
Set the target endpoint URL.
Sourcepub fn session_name(
self,
session_name: impl Into<UAString>,
) -> CreateSession<'a>
pub fn session_name( self, session_name: impl Into<UAString>, ) -> CreateSession<'a>
Set the session name.
Sourcepub fn client_certificate(self, client_certificate: X509) -> CreateSession<'a>
pub fn client_certificate(self, client_certificate: X509) -> CreateSession<'a>
Set the client certificate.
Sourcepub fn client_cert_from_store(
self,
certificate_store: &RwLock<RawRwLock, CertificateStore>,
) -> CreateSession<'a>
pub fn client_cert_from_store( self, certificate_store: &RwLock<RawRwLock, CertificateStore>, ) -> CreateSession<'a>
Load the client certificate from the certificate store.
Sourcepub fn session_timeout(self, session_timeout: f64) -> CreateSession<'a>
pub fn session_timeout(self, session_timeout: f64) -> CreateSession<'a>
Set the timeout for the session.
Sourcepub fn max_response_message_size(
self,
max_response_message_size: u32,
) -> CreateSession<'a>
pub fn max_response_message_size( self, max_response_message_size: u32, ) -> CreateSession<'a>
Set the requested maximum response message size.
Sourcepub fn nonce_length(self, nonce_length: usize) -> CreateSession<'a>
pub fn nonce_length(self, nonce_length: usize) -> CreateSession<'a>
Set the length of the client nonce used to generate this request.