pub struct DeleteMonitoredItems { /* private fields */ }Expand description
Deletes monitored items from a subscription by sending a DeleteMonitoredItemsRequest to the server.
See OPC UA Part 4 - Services 5.12.6 for complete description of the service and error responses.
Implementations
Sourceimpl DeleteMonitoredItems
impl DeleteMonitoredItems
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> DeleteMonitoredItems
pub fn diagnostics(self, bits: DiagnosticBits) -> DeleteMonitoredItems
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> DeleteMonitoredItems
pub fn timeout(self, timeout: Duration) -> DeleteMonitoredItems
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> DeleteMonitoredItems
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> DeleteMonitoredItems
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl DeleteMonitoredItems
impl DeleteMonitoredItems
Sourcepub fn new(subscription_id: u32, session: &Session) -> DeleteMonitoredItems
pub fn new(subscription_id: u32, session: &Session) -> DeleteMonitoredItems
Construct a new call to the DeleteMonitoredItems service.
Sourcepub fn new_manual(
subscription_id: u32,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: u32,
) -> DeleteMonitoredItems
pub fn new_manual( subscription_id: u32, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: u32, ) -> DeleteMonitoredItems
Construct a new call to the DeleteMonitoredItems service, setting header parameters manually.
Sourcepub fn items_to_delete(self, items_to_delete: Vec<u32>) -> DeleteMonitoredItems
pub fn items_to_delete(self, items_to_delete: Vec<u32>) -> DeleteMonitoredItems
Set the items to delete, overwriting any that were added previously.
Sourcepub fn item(self, item: u32) -> DeleteMonitoredItems
pub fn item(self, item: u32) -> DeleteMonitoredItems
Add a new item to delete.