pub struct DeleteNodes { /* private fields */ }Expand description
Delete nodes by sending a DeleteNodesRequest to the server.
See OPC UA Part 4 - Services 5.7.4 for complete description of the service and error responses.
Implementations
Sourceimpl DeleteNodes
impl DeleteNodes
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> DeleteNodes
pub fn diagnostics(self, bits: DiagnosticBits) -> DeleteNodes
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> DeleteNodes
pub fn timeout(self, timeout: Duration) -> DeleteNodes
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> DeleteNodes
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> DeleteNodes
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl DeleteNodes
impl DeleteNodes
Sourcepub fn new(session: &Session) -> DeleteNodes
pub fn new(session: &Session) -> DeleteNodes
Construct a new call to the DeleteNodes service.
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: u32,
) -> DeleteNodes
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: u32, ) -> DeleteNodes
Construct a new call to the DeleteNodes service, setting header parameters manually.
Sourcepub fn nodes_to_delete(
self,
nodes_to_delete: Vec<DeleteNodesItem>,
) -> DeleteNodes
pub fn nodes_to_delete( self, nodes_to_delete: Vec<DeleteNodesItem>, ) -> DeleteNodes
Set nodes to delete, overwriting any that were set previously.
Sourcepub fn node(self, reference: impl Into<DeleteNodesItem>) -> DeleteNodes
pub fn node(self, reference: impl Into<DeleteNodesItem>) -> DeleteNodes
Add a node to delete.