pub struct DeleteSubscriptions { /* private fields */ }Expand description
Deletes subscriptions by sending a DeleteSubscriptionsRequest to the server with the list
of subscriptions to delete.
See OPC UA Part 4 - Services 5.13.8 for complete description of the service and error responses.
Implementations
Sourceimpl DeleteSubscriptions
impl DeleteSubscriptions
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> DeleteSubscriptions
pub fn diagnostics(self, bits: DiagnosticBits) -> DeleteSubscriptions
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> DeleteSubscriptions
pub fn timeout(self, timeout: Duration) -> DeleteSubscriptions
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> DeleteSubscriptions
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> DeleteSubscriptions
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl DeleteSubscriptions
impl DeleteSubscriptions
Sourcepub fn new(session: &Session) -> DeleteSubscriptions
pub fn new(session: &Session) -> DeleteSubscriptions
Construct a new call to the DeleteSubscriptions service.
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: u32,
) -> DeleteSubscriptions
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: u32, ) -> DeleteSubscriptions
Construct a new call to the DeleteSubscriptions service, setting header parameters manually.
Sourcepub fn subscription_ids(self, subscription_ids: Vec<u32>) -> DeleteSubscriptions
pub fn subscription_ids(self, subscription_ids: Vec<u32>) -> DeleteSubscriptions
Set the subscription IDs to delete, overwriting any that were added previously.
Sourcepub fn subscription(self, subscription_id: u32) -> DeleteSubscriptions
pub fn subscription(self, subscription_id: u32) -> DeleteSubscriptions
Add a subscription ID to delete.