pub struct Read { /* private fields */ }Expand description
Builder for a call to the Read service.
See OPC UA Part 4 - Services 5.10.2 for complete description of the service and error responses.
Implementations
Sourceimpl Read
impl Read
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: u32,
) -> Read
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: u32, ) -> Read
Construct a new call to the Read service, setting header parameters manually.
Sourcepub fn timestamps_to_return(self, timestamps: TimestampsToReturn) -> Read
pub fn timestamps_to_return(self, timestamps: TimestampsToReturn) -> Read
Set timestamps to return.
Sourcepub fn nodes_to_read(self, nodes_to_read: Vec<ReadValueId>) -> Read
pub fn nodes_to_read(self, nodes_to_read: Vec<ReadValueId>) -> Read
Set nodes to read, overwriting any that were set previously.
Sourcepub fn node(self, node: ReadValueId) -> Read
pub fn node(self, node: ReadValueId) -> Read
Add a node to read.
Sourceimpl Read
impl Read
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Read
pub fn diagnostics(self, bits: DiagnosticBits) -> Read
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Read
pub fn timeout(self, timeout: Duration) -> Read
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Read
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Read
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.