pub struct SetPublishingMode { /* private fields */ }Expand description
Changes the publishing mode of subscriptions by sending a SetPublishingModeRequest to the server.
See OPC UA Part 4 - Services 5.13.4 for complete description of the service and error responses.
Implementations
Sourceimpl SetPublishingMode
impl SetPublishingMode
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> SetPublishingMode
pub fn diagnostics(self, bits: DiagnosticBits) -> SetPublishingMode
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> SetPublishingMode
pub fn timeout(self, timeout: Duration) -> SetPublishingMode
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> SetPublishingMode
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> SetPublishingMode
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl SetPublishingMode
impl SetPublishingMode
Sourcepub fn new(publishing_enabled: bool, session: &Session) -> SetPublishingMode
pub fn new(publishing_enabled: bool, session: &Session) -> SetPublishingMode
Construct a new call to the SetPublishingMode service.
Sourcepub fn new_manual(
publishing_enabled: bool,
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: u32,
) -> SetPublishingMode
pub fn new_manual( publishing_enabled: bool, session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: u32, ) -> SetPublishingMode
Construct a new call to the SetPublishingMode service, setting header parameters manually.
Sourcepub fn subscription_ids(self, subscription_ids: Vec<u32>) -> SetPublishingMode
pub fn subscription_ids(self, subscription_ids: Vec<u32>) -> SetPublishingMode
Set the subscription IDs to update, overwriting any that were added previously.
Sourcepub fn subscription(self, subscription_id: u32) -> SetPublishingMode
pub fn subscription(self, subscription_id: u32) -> SetPublishingMode
Add a subscription ID to update.