pub struct Write { /* private fields */ }Expand description
Writes values to nodes by sending a WriteRequest to the server. Note that some servers may reject DataValues
containing source or server timestamps.
See OPC UA Part 4 - Services 5.10.4 for complete description of the service and error responses.
Implementations
Sourceimpl Write
impl Write
Sourcepub fn diagnostics(self, bits: DiagnosticBits) -> Write
pub fn diagnostics(self, bits: DiagnosticBits) -> Write
Set requested diagnostic bits.
Sourcepub fn timeout(self, timeout: Duration) -> Write
pub fn timeout(self, timeout: Duration) -> Write
Set the timeout for this request. Defaults to session timeout.
Sourcepub fn audit_entry_id(self, entry: impl Into<UAString>) -> Write
pub fn audit_entry_id(self, entry: impl Into<UAString>) -> Write
Set the audit entry ID for the request.
Sourcepub fn header(&self) -> &RequestHeader
pub fn header(&self) -> &RequestHeader
Get the request header.
Sourceimpl Write
impl Write
Sourcepub fn new_manual(
session_id: u32,
timeout: Duration,
auth_token: NodeId,
request_handle: u32,
) -> Write
pub fn new_manual( session_id: u32, timeout: Duration, auth_token: NodeId, request_handle: u32, ) -> Write
Construct a new call to the Write service, setting header parameters manually.
Sourcepub fn nodes_to_write(self, nodes_to_write: Vec<WriteValue>) -> Write
pub fn nodes_to_write(self, nodes_to_write: Vec<WriteValue>) -> Write
Set nodes to write, overwriting any that were set previously.
Sourcepub fn node(self, node: impl Into<WriteValue>) -> Write
pub fn node(self, node: impl Into<WriteValue>) -> Write
Add a write value.