AsyncSecureChannel

Struct AsyncSecureChannel 

pub struct AsyncSecureChannel { /* private fields */ }
Wrapper around an open secure channel

Implementations

Source

impl AsyncSecureChannel

pub fn request_handle(&self) -> u32

Get the next request handle on the channel.

pub fn endpoint_info(&self) -> &EndpointInfo

Get the target endpoint of the secure channel.

pub fn encoding_context(&self) -> &RwLock<RawRwLock, ContextOwned>

Get the current global encoding context in use by this channel.

pub fn set_auth_token(&self, token: NodeId)

Set the active authentication token for this channel.

Source

impl AsyncSecureChannel

pub fn new( certificate_store: Arc<RwLock<RawRwLock, CertificateStore>>, endpoint_info: EndpointInfo, session_retry_policy: SessionRetryPolicy, ignore_clock_skew: bool, auth_token: Arc<ArcSwapAny<Arc<NodeId>>>, transport_config: TransportConfiguration, channel_lifetime: u32, encoding_context: Arc<RwLock<RawRwLock, ContextOwned>>, ) -> AsyncSecureChannel

Create a new client secure channel.

pub async fn send( &self, request: impl Into<RequestMessage>, timeout: Duration, ) -> Result<ResponseMessage, StatusCode>

Send a message on the secure channel, and wait for a response.

pub async fn connect<T>( &self, connector: &T, ) -> Result<SecureChannelEventLoop<<T as Connector>::Transport>, StatusCode>
where T: Connector,

Attempt to establish a connection using this channel, returning an event loop for polling the connection.

pub async fn connect_no_retry<T>( &self, connector: &T, ) -> Result<SecureChannelEventLoop<<T as Connector>::Transport>, StatusCode>
where T: Connector,

Connect to the server without attempting to retry if it fails.

pub async fn close_channel(&self)

Close the secure channel, optionally wait for the channel to close.