pub struct DirectConnectionSource;Expand description
Connection source for a direct OPC/TCP binary connection. This is the default connection source used by the session builder, and by far the most common when connecting to an OPC-UA server.