pub struct SessionRetryPolicy { /* private fields */ }Expand description
Session retry policy.
Configure the maximum delay between reconnect attempts, the initial delay between reconnect attempts, and the maximum number of reconnect attempts.
Implementations
Sourceimpl SessionRetryPolicy
impl SessionRetryPolicy
Sourcepub const DEFAULT_RETRY_LIMIT: u32 = 10
pub const DEFAULT_RETRY_LIMIT: u32 = 10
Default maximum number of retries.
Sourcepub const DEFAULT_INITIAL_SLEEP_MS: u64 = 500
pub const DEFAULT_INITIAL_SLEEP_MS: u64 = 500
Default initial delay between requests in milliseconds.
Sourcepub const DEFAULT_MAX_SLEEP_MS: u64 = 30000
pub const DEFAULT_MAX_SLEEP_MS: u64 = 30000
Default maximum delay between requests in milliseconds.
Sourcepub fn new(
max_sleep: Duration,
retry_limit: Option<u32>,
initial_sleep: Duration,
) -> SessionRetryPolicy
pub fn new( max_sleep: Duration, retry_limit: Option<u32>, initial_sleep: Duration, ) -> SessionRetryPolicy
Create a new session retry policy.
Sourcepub fn infinity(
max_sleep: Duration,
initial_sleep: Duration,
) -> SessionRetryPolicy
pub fn infinity( max_sleep: Duration, initial_sleep: Duration, ) -> SessionRetryPolicy
Retry forever with the given max delay and initial delay.
Sourcepub fn never() -> SessionRetryPolicy
pub fn never() -> SessionRetryPolicy
Never reconnect.