Shared implementaton of an OPC-UA buffer, handling encoding of data and the state of a communication channel.
Structs
- Send
Buffer - General implementation of a buffer of outgoing messages.
Shared implementaton of an OPC-UA buffer, handling encoding of data and the state of a communication channel.