pub struct AsymmetricSecurityHeader {
pub security_policy_uri: UAString,
pub sender_certificate: ByteString,
pub receiver_certificate_thumbprint: ByteString,
}Expand description
Security header for asymmetric encryption.
Fields
security_policy_uri: UAStringSecurity policy URI.
sender_certificate: ByteStringSender certificate as a byte string.
receiver_certificate_thumbprint: ByteStringThumbprint of the receiver certificate as a byte string.
Implementations
Sourceimpl AsymmetricSecurityHeader
impl AsymmetricSecurityHeader
Sourcepub fn none() -> AsymmetricSecurityHeader
pub fn none() -> AsymmetricSecurityHeader
Create a new asymmetric security header with no security policy.
Sourcepub fn new(
security_policy: SecurityPolicy,
sender_certificate: &X509,
receiver_certificate_thumbprint: ByteString,
) -> AsymmetricSecurityHeader
pub fn new( security_policy: SecurityPolicy, sender_certificate: &X509, receiver_certificate_thumbprint: ByteString, ) -> AsymmetricSecurityHeader
Create a new asymmetric security header.