SequenceNumberHandle

Struct SequenceNumberHandle 

pub struct SequenceNumberHandle { /* private fields */ }
Utility for managing sequence numbers

Implementations

Source

impl SequenceNumberHandle

pub fn new(is_legacy: bool) -> SequenceNumberHandle

Create a new sequence number handle Uses either legacy or non-legacy sequence numbers, see https://reference.opcfoundation.org/Core/Part6/v105/docs/6.7.2.4

pub fn max_value(&self) -> u32

Get the maximum value of the sequence number. This is the maximum value the sequence number can have, after which it will overflow.

pub fn is_legacy(&self) -> bool

Get whether the sequence number handle uses legacy sequence numbers or not.

pub fn min_value(&self) -> u32

Get the minimum value of the sequence number.

pub fn current(&self) -> u32

Get the current sequence number, which is the next value that will be used.

pub fn set(&mut self, value: u32)

Set the value of the sequence number handle.

pub fn increment(&mut self, value: u32)

Increment the sequence number by the given value.

pub fn validate_and_increment( &mut self, incoming_sequence_number: u32, ) -> Result<(), Error>

Validate the incoming sequence number against the expected value, and increment the sequence number if valid.