pub enum Message {
Hello(HelloMessage),
Acknowledge(AcknowledgeMessage),
Error(ErrorMessage),
Chunk(MessageChunk),
ReverseHello(ReverseHelloMessage),
}Expand description
Message type sent over OPC-UA streams.
Variants
Hello(HelloMessage)
Hello message, the first part of a connection negotiation.
Acknowledge(AcknowledgeMessage)
Acknowledge message, acceptance of negotiation.
Error(ErrorMessage)
Error message, final fatal message describing reason for why the channel will be closed.
Chunk(MessageChunk)
Part of a general OPC-UA message.
ReverseHello(ReverseHelloMessage)
Reverse Hello message, sent by the server to the client.