Runtime

Struct Runtime 

pub struct Runtime { /* private fields */ }
The Runtime is for debugging / diagnostics purposes and tracks which substantial system objects components are in existence. It can be used to detect if something has shutdown or not.

Implementations

Source

impl Runtime

pub fn components(&self) -> Vec<String>

pub fn register_component(&self, key: &str)

pub fn deregister_component(&self, key: &str)