byte_string

Function byte_string 

pub fn byte_string(number_of_bytes: usize) -> ByteString
Create a byte string with a number of random characters. Can be used to create a nonce or a similar reason.