pub struct ParsedContentFilter { /* private fields */ }Expand description
Parsed version of the raw ContentFilter.
Implementations
Sourceimpl ParsedContentFilter
impl ParsedContentFilter
Sourcepub fn evaluate(
&self,
item: impl AttributeQueryable,
type_tree: &dyn TypeTree,
) -> bool
pub fn evaluate( &self, item: impl AttributeQueryable, type_tree: &dyn TypeTree, ) -> bool
Evaluate the content filter, returning true if it
passes the filter.
Sourceimpl ParsedContentFilter
impl ParsedContentFilter
Sourcepub fn empty() -> ParsedContentFilter
pub fn empty() -> ParsedContentFilter
Create a new empty content filter.
Sourcepub fn parse(
filter: ContentFilter,
type_tree: &dyn TypeTree,
allow_attribute_operands: bool,
banned_operators: &[FilterOperator],
) -> (ContentFilterResult, Result<ParsedContentFilter, StatusCode>)
pub fn parse( filter: ContentFilter, type_tree: &dyn TypeTree, allow_attribute_operands: bool, banned_operators: &[FilterOperator], ) -> (ContentFilterResult, Result<ParsedContentFilter, StatusCode>)
Create a new content filter from the raw ContentFilter.
If allow_attribute_operands is false, parsing will fail
if it encounters an attribute operand.
banned_operators is a list of operators that are not allowed in the filter.
If any of these operators are present, the parsing will fail with
StatusCode::BadFilterOperatorUnsupported.