pub struct ParsedEventFilter { /* private fields */ }Expand description
Parsed version of the raw EventFilter.
Implementations
Sourceimpl ParsedEventFilter
impl ParsedEventFilter
Sourcepub fn new(
raw: EventFilter,
type_tree: &dyn TypeTree,
) -> (EventFilterResult, Result<ParsedEventFilter, StatusCode>)
pub fn new( raw: EventFilter, type_tree: &dyn TypeTree, ) -> (EventFilterResult, Result<ParsedEventFilter, StatusCode>)
Try to build a parsed filter from a raw EventFilter.
This may fail, but will always return an EventFilterResult.