VariableBuilder

Struct VariableBuilder 

pub struct VariableBuilder { /* private fields */ }
A builder for constructing a node of same name. This can be used as an easy way to create a node and the references it has to another node in a simple fashion.

Implementations

Source

impl VariableBuilder

pub fn new<T, S>( node_id: &NodeId, browse_name: T, display_name: S, ) -> VariableBuilder

Creates a builder for a node. All nodes are required to su

pub fn get_node_id(&self) -> &NodeId

Get the node ID of the node being built.

pub fn is_valid(&self) -> bool

Tests that the builder is in a valid state to build or insert the node.

pub fn description<V>(self, description: V) -> VariableBuilder
where V: Into<LocalizedText>,

Sets the description of the node

pub fn reference<T>( self, node_id: T, reference_type_id: ReferenceTypeId, reference_direction: ReferenceDirection, ) -> VariableBuilder
where T: Into<NodeId>,

Adds a reference to the node

pub fn organizes<T>(self, organizes_id: T) -> VariableBuilder
where T: Into<NodeId>,

Indicates this node organizes another node by its id.

pub fn organized_by<T>(self, organized_by_id: T) -> VariableBuilder
where T: Into<NodeId>,

Indicates this node is organised by another node by its id

pub fn build(self) -> Variable

Yields a built node. This function will panic if the node is invalid. Note that calling this function discards any references for the node, so there is no purpose in adding references if you intend to call this method.

pub fn insert(self, address_space: &mut impl NodeInsertTarget) -> bool

Inserts the node into the address space, including references. This function will panic if the node is in an invalid state.

Source

impl VariableBuilder

pub fn component_of<T>(self, component_of_id: T) -> VariableBuilder
where T: Into<NodeId>,

Add an inverse HasComponent reference to the given node.

pub fn has_component<T>(self, has_component_id: T) -> VariableBuilder
where T: Into<NodeId>,

Add a HasComponent reference to the given node.

Source

impl VariableBuilder

pub fn has_property<T>(self, has_component_id: T) -> VariableBuilder
where T: Into<NodeId>,

Add a HasProperty reference to the given node.

pub fn property_of<T>(self, component_of_id: T) -> VariableBuilder
where T: Into<NodeId>,

Add an inverse HasProperty reference to the given node.

Source

impl VariableBuilder

pub fn value(self, value: impl Into<Variant>) -> VariableBuilder

Sets the value of the variable.

pub fn data_type(self, data_type: impl Into<NodeId>) -> VariableBuilder

Sets the data type of the variable.

pub fn historizing(self, historizing: bool) -> VariableBuilder

Sets the historizing flag for the variable.

pub fn access_level(self, access_level: AccessLevel) -> VariableBuilder

Sets the access level for the variable.

pub fn user_access_level( self, user_access_level: AccessLevel, ) -> VariableBuilder

Sets the user access level for the variable.

pub fn value_rank(self, value_rank: i32) -> VariableBuilder

Sets the value rank for the variable.

pub fn array_dimensions(self, array_dimensions: &[u32]) -> VariableBuilder

Sets the array dimensions for the variable.

pub fn write_mask(self, write_mask: WriteMask) -> VariableBuilder

Set the write mask for this variable.

pub fn writable(self) -> VariableBuilder

Makes the variable writable (by default it isn’t)

pub fn history_readable(self) -> VariableBuilder

Makes the variable history-readable

pub fn history_updatable(self) -> VariableBuilder

Makes the variable history-updateable

pub fn minimum_sampling_interval( self, minimum_sampling_interval: f64, ) -> VariableBuilder

Sets the minimum sampling interval for the variable.

pub fn has_type_definition<T>(self, type_id: T) -> VariableBuilder
where T: Into<NodeId>,

Add a reference to the variable indicating it has a type of another node.

pub fn has_modelling_rule<T>(self, type_id: T) -> VariableBuilder
where T: Into<NodeId>,

Add a reference to the variable indicating it has a modelling rule of another node.