DefaultAuthenticator

Struct DefaultAuthenticator 

pub struct DefaultAuthenticator { /* private fields */ }
A simple authenticator that keeps a map of valid users in memory. In production applications you will almost always want to create your own custom authenticator.

Implementations

Source

impl DefaultAuthenticator

pub fn new(users: BTreeMap<String, ServerUserToken>) -> DefaultAuthenticator

Create a new default authenticator with the given set of users.