pub struct UserToken(pub String);Expand description
A unique identifier for a user. Distinct from a client/session, a user can have multiple sessions at the same time, and is typically the value we use to control access.
Tuple Fields
0: StringImplementations