DiagnosticsNodeManager

Struct DiagnosticsNodeManager 

pub struct DiagnosticsNodeManager { /* private fields */ }
Node manager handling nodes in the server hierarchy that are not part of the core namespace, and that are somehow dynamic. This includes the node for each namespace, session diagnostics, etc.