LocalValue

Struct LocalValue 

pub struct LocalValue<T> { /* private fields */ }
Wrapper around a value in memory, used for metrics. We need to use a mutex to keep track of when the value was last updated.

Implementations

Source

impl<T> LocalValue<T>
where T: Clone + IntoVariant,

pub fn new(value: T) -> LocalValue<T>

Create a new LocalValue with the given value.

pub fn modify(&self, fun: impl FnOnce(&mut T))

Update the value and set the timestamp.

pub fn set(&self, value: T)

Set the value and update the timestamp.

pub fn sample(&self) -> DataValue

Get the current value as a datavalue.

pub fn get(&self) -> T

Get the current value.

pub fn get_with_time(&self) -> (T, DateTime)

Get the current value and timestamp.

Source

impl LocalValue<u32>

pub fn increment(&self)

Convenience function to increment the value.

pub fn decrement(&self)

Convenience function to decrement the value.