NamespaceMetadata

Struct NamespaceMetadata 

pub struct NamespaceMetadata {
    pub default_access_restrictions: AccessRestrictionType,
    pub default_role_permissions: Option<Vec<RolePermissionType>>,
    pub default_user_role_permissions: Option<Vec<RolePermissionType>>,
    pub is_namespace_subset: Option<bool>,
    pub namespace_publication_date: Option<DateTime>,
    pub namespace_uri: String,
    pub namespace_version: Option<String>,
    pub static_node_id_types: Option<Vec<IdType>>,
    pub static_numeric_node_id_range: Option<Vec<NumericRange>>,
    pub static_string_node_id_pattern: Option<String>,
    pub namespace_index: u16,
}
Namespace metadata. This is visible in the namespace array under the Server node.

Fields

default_access_restrictions: AccessRestrictionType

Default access restrictions on this namespace.

default_role_permissions: Option<Vec<RolePermissionType>>

Default role permissions on this namespace.

default_user_role_permissions: Option<Vec<RolePermissionType>>

Default user role permissions on this namespace.

is_namespace_subset: Option<bool>

Whether this namespace is a subset of the full namespace.

namespace_publication_date: Option<DateTime>

Time this namespace was last updated.

namespace_uri: String

Namespace URI.

namespace_version: Option<String>

Namespace version.

static_node_id_types: Option<Vec<IdType>>

List of ID types in this namespace.

static_numeric_node_id_range: Option<Vec<NumericRange>>

List of ranges for numeric node IDs on static nodes in this namespace.

static_string_node_id_pattern: Option<String>

Pattern that applies to string node IDs on static nodes in this namespace.

namespace_index: u16

Namespace index on the server.