ServerDiagnostics

Struct ServerDiagnostics 

pub struct ServerDiagnostics {
    pub summary: ServerDiagnosticsSummary,
    pub enabled: bool,
}
The server diagnostics struct, containing shared types for various forms of server diagnostics.

Fields

summary: ServerDiagnosticsSummary

Server diagnostics summary.

enabled: bool

Whether diagnostics are enabled or not. Set on server startup.

Implementations

Source

impl ServerDiagnostics

pub fn is_mapped(&self, variable_id: VariableId) -> bool

Check if the given variable ID is managed by this object.

pub fn get(&self, variable_id: VariableId) -> Option<DataValue>

Get the value of a diagnostics element by its ID.

pub fn set_current_session_count(&self, count: u32)

Set the current session count.

pub fn set_current_subscription_count(&self, count: u32)

Set the current subscription count.

pub fn inc_session_count(&self)

Increment the cumulated session count.

pub fn inc_subscription_count(&self)

Increment the cumulated subscription count.

pub fn inc_rejected_requests(&self)

Increment the rejected requests count.

pub fn inc_security_rejected_requests(&self)

Increment the security rejected requests count.

pub fn inc_security_rejected_session_count(&self)

Increment the security rejected session count.

pub fn set_server_view_count(&self, count: u32)

Set the number of server-created views.

pub fn inc_session_abort_count(&self)

Increment the session abort count.

pub fn inc_session_timeout_count(&self)

Increment the session timeout count.

pub fn set_publishing_interval_count(&self, count: u32)

Set the number of publishing intervals supported by the server.