IdentityToken

Enum IdentityToken 

pub enum IdentityToken {
    None,
    Anonymous(AnonymousIdentityToken),
    UserName(UserNameIdentityToken),
    X509(X509IdentityToken),
    IssuedToken(IssuedIdentityToken),
    Invalid(ExtensionObject),
}
Identity token representation on the server, decoded from the client.

Variants



None

No identity token specified at all.



Anonymous(AnonymousIdentityToken)

Identity token for anonymous access.



UserName(UserNameIdentityToken)

Identity token for user name and password.



X509(X509IdentityToken)

Identity token for X.509 certificate.



IssuedToken(IssuedIdentityToken)

Identity token for an issued identity token, i.e. OAuth.



Invalid(ExtensionObject)

Invalid identity token with some unknown structure.

Implementations

Source

impl IdentityToken

pub fn new(o: ExtensionObject) -> IdentityToken

Decode an identity token from an extension object received from the client. Returns Invalid if decoding failed.