pub enum AddReferenceResult {
Added,
Rejected,
Full(ReferenceDescription),
}Expand description
Result of adding a reference to a browse node.
Variants
Added
The reference was added
Rejected
The reference does not match the filters and was rejected
Full(ReferenceDescription)
The reference does match the filters, but the node is full.