pub fn get_namespaces_for_user(
context: &RequestContext,
node_managers: &impl NodeManagerCollection,
) -> NamespaceMapExpand description
Get the namespaces visible to the current user by calling namespaces_for_user
on each node manager.
pub fn get_namespaces_for_user(
context: &RequestContext,
node_managers: &impl NodeManagerCollection,
) -> NamespaceMapGet the namespaces visible to the current user by calling namespaces_for_user
on each node manager.