get_node_metadata

Function get_node_metadata 

pub async fn get_node_metadata(
    context: &RequestContext,
    node_managers: &impl NodeManagerCollection,
    ids: &[NodeId],
) -> Vec<Option<NodeMetadata>>
Fetch external references by requesting them from their owning node manager.

This calls resolve_external_references on each node manager with the ids in ids that they return true on owns_node for.