Module memory

Module memory 

The implementation of InMemoryNodeManager, a generic node manager that keeps all its nodes in memory, and delegates implementing details to a type implementing InMemoryNodeManagerImpl.

Structs

CoreNodeManagerBuilder
Builder for the CoreNodeManager.
CoreNodeManagerImpl
Node manager impl for the core namespace.
InMemoryNodeManager
A node manager that stores its nodes in an in-memory AddressSpace. This only supports a static list of namespaces, and a attributes stored in memory.
InMemoryNodeManagerBuilder
Builder for the in-memory node manager.
SimpleNodeManagerBuilder
Builder for the SimpleNodeManager.
SimpleNodeManagerImpl
Node manager designed to deal with simple, entirely in-memory, synchronous OPC-UA servers.

Traits

InMemoryNodeManagerImpl
Trait for user-provided implementation of the InMemoryNodeManager
InMemoryNodeManagerImplBuilder
Trait for constructing an InMemoryNodeManagerImpl.

Functions

simple_node_manager
Create a node manager builder for the simple node manager with the given namespace and name.
simple_node_manager_imports
Create a new simple node manager that imports from the given list of NodeSetImports.

Type Aliases

CoreNodeManager
Node manager for the core namespace.
SimpleNodeManager
A simple in-memory node manager with utility methods for updating the address space, and a mechanism for setting callbacks on Read and Write of values.