pub struct AddNodeItem { /* private fields */ }Expand description
Container for a single node being added in an AddNode service call.
Implementations
Sourceimpl AddNodeItem
impl AddNodeItem
Sourcepub fn set_result(&mut self, node_id: NodeId, status: StatusCode)
pub fn set_result(&mut self, node_id: NodeId, status: StatusCode)
Set the result of the operation. node_id is the node ID of the created node.
Sourcepub fn parent_node_id(&self) -> &ExpandedNodeId
pub fn parent_node_id(&self) -> &ExpandedNodeId
The requested parent node ID.
Sourcepub fn reference_type_id(&self) -> &NodeId
pub fn reference_type_id(&self) -> &NodeId
The requested reference type ID.
Sourcepub fn requested_new_node_id(&self) -> &NodeId
pub fn requested_new_node_id(&self) -> &NodeId
The requested new node ID. May be null, in which case the node manager picks the new node ID.
Sourcepub fn browse_name(&self) -> &QualifiedName
pub fn browse_name(&self) -> &QualifiedName
Requested browse name of the new node.
Sourcepub fn node_class(&self) -> NodeClass
pub fn node_class(&self) -> NodeClass
Requested node class of the new node.
Sourcepub fn node_attributes(&self) -> &AddNodeAttributes
pub fn node_attributes(&self) -> &AddNodeAttributes
Collection of requested attributes for the new node.
Sourcepub fn type_definition_id(&self) -> &ExpandedNodeId
pub fn type_definition_id(&self) -> &ExpandedNodeId
Requested type definition ID.
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Current result status code.
Sourcepub fn diagnostic_bits(&self) -> DiagnosticBits
pub fn diagnostic_bits(&self) -> DiagnosticBits
Header diagnostic bits for requesting operation-level diagnostics.
Sourcepub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)
pub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)
Set diagnostic infos, you don’t need to do this if
diagnostic_bits are not set.