pub struct BrowsePathItem<'a> { /* private fields */ }Expand description
Container for a node being discovered in a browse path operation.
Implementations
Sourceimpl<'a> BrowsePathItem<'a>
impl<'a> BrowsePathItem<'a>
Sourcepub fn path(&self) -> &'a [RelativePathElement]
pub fn path(&self) -> &'a [RelativePathElement]
Full browse path for this item.
Sourcepub fn add_element(
&mut self,
node: NodeId,
relative_depth: usize,
unmatched_browse_name: Option<QualifiedName>,
)
pub fn add_element( &mut self, node: NodeId, relative_depth: usize, unmatched_browse_name: Option<QualifiedName>, )
Add a path result element.
Sourcepub fn set_status(&mut self, status: StatusCode)
pub fn set_status(&mut self, status: StatusCode)
Set the status code for this operation.
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the current result status code.
Sourcepub fn iteration_number(&self) -> usize
pub fn iteration_number(&self) -> usize
Get the current interation number.
Sourcepub fn unmatched_browse_name(&self) -> Option<&QualifiedName>
pub fn unmatched_browse_name(&self) -> Option<&QualifiedName>
Get the last unmatched browse name, if present.
Sourcepub fn set_browse_name_matched(&mut self, node_manager_index: usize)
pub fn set_browse_name_matched(&mut self, node_manager_index: usize)
Set the browse name as matched by the node manager given by node_manager_index.