DeleteReferenceItem

Struct DeleteReferenceItem 

pub struct DeleteReferenceItem { /* private fields */ }
Container for a single reference being deleted in an DeleteReferences service call.

Implementations

Source

impl DeleteReferenceItem

pub fn source_node_id(&self) -> &NodeId

Source node ID of the reference being deleted.

pub fn reference_type_id(&self) -> &NodeId

Reference type ID of the reference being deleted.

pub fn target_node_id(&self) -> &ExpandedNodeId

Target node ID of the reference being deleted.

pub fn set_source_result(&mut self, status: StatusCode)

Set the result of this operation for the source end of the reference.

pub fn set_target_result(&mut self, status: StatusCode)

Set the result of this operation for the target end of the reference.

pub fn is_forward(&self) -> bool

Direction of the reference being deleted.

pub fn target_status(&self) -> StatusCode

Current target status.

pub fn source_status(&self) -> StatusCode

Current source status.

pub fn delete_bidirectional(&self) -> bool

Whether to delete the reference in both directions.

pub fn diagnostic_bits(&self) -> DiagnosticBits

Header diagnostic bits for requesting operation-level diagnostics.

pub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)

Set diagnostic infos, you don’t need to do this if diagnostic_bits are not set.