pub struct ExternalReference { /* private fields */ }Expand description
A reference pointing to some node in a different node manager.
Implementations
Sourceimpl ExternalReference
impl ExternalReference
Sourcepub fn new(
target_id: ExpandedNodeId,
reference_type_id: NodeId,
direction: ReferenceDirection,
) -> ExternalReference
pub fn new( target_id: ExpandedNodeId, reference_type_id: NodeId, direction: ReferenceDirection, ) -> ExternalReference
Create a new external reference.
Sourcepub fn into_reference(self, meta: NodeMetadata) -> ReferenceDescription
pub fn into_reference(self, meta: NodeMetadata) -> ReferenceDescription
Create a reference description from this and a NodeMetadata object.