HistoryUpdateNode

Struct HistoryUpdateNode 

pub struct HistoryUpdateNode { /* private fields */ }
History update details for one node.

Implementations

Source

impl HistoryUpdateNode

pub fn set_status(&mut self, status: StatusCode)

Set the result status of this history operation.

pub fn status(&self) -> StatusCode

Get the current status.

pub fn set_operation_results( &mut self, operation_results: Option<Vec<StatusCode>>, )

Set the operation results. If present the length must match the length of the entries in the history update details.

pub fn details(&self) -> &HistoryUpdateDetails

Get a reference to the history update details describing the history update to execute.