pub struct MethodCall { /* private fields */ }Expand description
Container for a single method call in a Call service call.
Implementations
Sourceimpl MethodCall
impl MethodCall
Sourcepub fn set_argument_error(&mut self, argument_results: Vec<StatusCode>)
pub fn set_argument_error(&mut self, argument_results: Vec<StatusCode>)
Set the argument results to a list of errors.
This will update the status to BadInvalidArgument.
The length of argument_results must be equal to the length of arguments.
Sourcepub fn set_status(&mut self, status: StatusCode)
pub fn set_status(&mut self, status: StatusCode)
Set the result of this method call.
Sourcepub fn set_outputs(&mut self, outputs: Vec<Variant>)
pub fn set_outputs(&mut self, outputs: Vec<Variant>)
Set the outputs of this method call.
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the current status.
Sourcepub fn diagnostic_bits(&self) -> DiagnosticBits
pub fn diagnostic_bits(&self) -> DiagnosticBits
Header diagnostic bits for requesting operation-level diagnostics.
Sourcepub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)
pub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)
Set diagnostic infos, you don’t need to do this if
diagnostic_bits are not set.