ReadNode

Struct ReadNode 

pub struct ReadNode { /* private fields */ }
Container for a single item in a Read service call.

Implementations

Source

impl ReadNode

pub fn status(&self) -> StatusCode

Get the current result status code.

pub fn node(&self) -> &ParsedReadValueId

Get the node/attribute pair to read.

pub fn set_result(&mut self, result: DataValue)

Set the result of this read operation.

pub fn set_error(&mut self, status: StatusCode)

Set the result of this read operation to an error with no value or timestamp. Use this not if the value is an error, but if the read failed.

pub fn diagnostic_bits(&self) -> DiagnosticBits

Header diagnostic bits for requesting operation-level diagnostics.

pub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)

Set diagnostic infos, you don’t need to do this if diagnostic_bits are not set.