pub struct ServerContext {
pub node_managers: NodeManagersRef,
pub subscriptions: Arc<SubscriptionCache>,
pub info: Arc<ServerInfo>,
pub authenticator: Arc<dyn AuthManager>,
pub type_tree: Arc<RwLock<RawRwLock, DefaultTypeTree>>,
pub type_tree_getter: Arc<dyn TypeTreeForUser>,
pub status: Arc<ServerStatusWrapper>,
}Expand description
General server context, passed when requests are made to the node managers on behalf of the server itself, and not a user.
Fields
node_managers: NodeManagersRefWeak reference to the node manager collection.
subscriptions: Arc<SubscriptionCache>Cache containing the subscriptions managed by the server.
info: Arc<ServerInfo>General server state and configuration.
authenticator: Arc<dyn AuthManager>Global authenticator object.
type_tree: Arc<RwLock<RawRwLock, DefaultTypeTree>>The server default type tree.
type_tree_getter: Arc<dyn TypeTreeForUser>Wrapper to get a type tree for a specific user.
status: Arc<ServerStatusWrapper>Wrapper managing the ServerStatus server variable.