SyncSampler

Struct SyncSampler 

pub struct SyncSampler { /* private fields */ }
Utility for periodically sampling a list of nodes/attributes. When using this you should call run to start the sampler once you have access to the server context.

Implementations

Source

impl SyncSampler

pub fn new() -> SyncSampler

Create a new sync sampler.

pub fn run(&self, interval: Duration, subscriptions: Arc<SubscriptionCache>)

Start the sampler. You should avoid calling this multiple times, typically this is called in build_nodes or init. The sampler will automatically shut down once it is dropped.

pub fn add_sampler( &self, node_id: NodeId, attribute: AttributeId, sampler: impl FnMut() -> Option<DataValue> + Send + 'static, mode: MonitoringMode, handle: MonitoredItemHandle, sampling_interval: Duration, )

Add a periodic sampler for a monitored item. Note that if a sampler for the given nodeId/attributeId pair already exists, no new sampler will be created. It is assumed that each nodeId/attributeId pair has a single sampler function.

pub fn update_sampler( &self, node_id: &NodeId, attribute: AttributeId, handle: MonitoredItemHandle, sampling_interval: Duration, )

Update the sample rate of a monitored item. The smallest registered sampling interval for each nodeId/attributeId pair is used. This is also bounded from below by the rate of the SyncSampler itself.

pub fn set_sampler_mode( &self, node_id: &NodeId, attribute: AttributeId, handle: MonitoredItemHandle, mode: MonitoringMode, )

Set the sampler mode for a node.

pub fn remove_sampler( &self, node_id: &NodeId, attribute: AttributeId, handle: MonitoredItemHandle, )

Remove a sampler. The actual sampler will only be fully removed once all samplers for the attribute are gone.