NodeManagerCollection

Trait NodeManagerCollection 

pub trait NodeManagerCollection {
    // Required method
    fn iter_node_managers(
        &self,
    ) -> impl Iterator<Item = Arc<dyn NodeManager + Sync + Send>>;
}
Trait for a collection of node managers, to allow abstracting over weak or strong references to the node manager collection.

Required Methods

fn iter_node_managers( &self, ) -> impl Iterator<Item = Arc<dyn NodeManager + Sync + Send>>

Iterate over the node managers on the server.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors