TypeTreeForUserStatic

Trait TypeTreeForUserStatic 

pub trait TypeTreeForUserStatic: Send + Sync {
    // Required method
    fn get_type_tree<'a>(&'a self) -> Box<dyn TypeTreeReadContext + 'a>;
}
Trait for providing a static reference to the type tree for a specific user. This allows subscriptions to hold a reference to the type tree.

Required Methods

fn get_type_tree<'a>(&'a self) -> Box<dyn TypeTreeReadContext + 'a>

Get the type tree read context. This may lock.

Implementations on Foreign Types

Source

impl<T> TypeTreeForUserStatic for RwLock<RawRwLock, T>
where T: TypeTree + Send + Sync + 'static,

Source

fn get_type_tree<'a>(&'a self) -> Box<dyn TypeTreeReadContext + 'a>

Implementors