SubscriptionDataNotifier

Struct SubscriptionDataNotifier 

pub struct SubscriptionDataNotifier<'a> { /* private fields */ }
Handle for notifying the subscription cache of a batch of changes, without allocating NodeIds unnecessarily. Notifications are actually submitted once the notifier is dropped.

Implementations

Source

impl<'a> SubscriptionDataNotifier<'a>

pub fn notify_for<'b, 'c>( &'b mut self, node_id: impl IntoNodeIdRef<'c>, attribute_id: AttributeId, ) -> Option<SubscriptionDataNotifierBatch<'b>>

Maybe sample for the given node ID and attribute ID.

This allows you to only sample when a user is listening.

Example
if let Some(mut notif) = notifier.notify_for((1, 123), AttributeId::Value) {
    notif.value(Variant::Int32(42), DateTime::now());
    notif.value(Variant::Int32(45), DateTime::now());
}
pub fn notify( &mut self, node_id: impl IntoNodeIdRef<'a>, attribute_id: AttributeId, value: impl Into<DataValue>, )

Notify the subscription cache of a change in value for the given node ID and attribute ID.

Arguments
  • node_id - The node ID or reference to node ID for the changed node.
  • attribute_id - The attribute ID of the changed value. Note that this may not be EventNotifier.
  • value - The new value as a DataValue or something convertible to a DataValue.