SubscriptionDataNotifierBatch

Struct SubscriptionDataNotifierBatch 

pub struct SubscriptionDataNotifierBatch<'a> { /* private fields */ }
Notifier for a specific node.

Implementations

Source

impl<'a> SubscriptionDataNotifierBatch<'a>

pub fn data_value(&mut self, value: impl Into<DataValue>)

Notify the referenced node of a change in value by providing a DataValue.

pub fn data_value_to_item( &mut self, value: impl Into<DataValue>, handle: &MonitoredItemHandle, )

Submit a data value to a specific monitored item.

pub fn value(&mut self, value: impl Into<Variant>, source_timestamp: DateTime)

Notify the referenced node of a change in value by providing a Variant and source timestamp.

pub fn entries<'b>( &'b self, ) -> impl Iterator<Item = (&'a MonitoredItemHandle, &'a MonitoredItemEntry)> + 'a

Get an iterator over the matched monitored item entries. This can be used to conditionally sample using parameters for each monitored item.

This only returns monitored item entries that are enabled.