SubscriptionEventNotifier

Struct SubscriptionEventNotifier 

pub struct SubscriptionEventNotifier<'a, 'b> { /* private fields */ }
Handle for notifying the subscription cache of a batch of events, without allocating NodeIds unnecessarily. Notifications are actually submitted once the notifier is dropped.

Implementations

Source

impl<'a, 'b> SubscriptionEventNotifier<'a, 'b>

pub fn notify_for<'c>( &'c mut self, node_id: impl IntoNodeIdRef<'a>, ) -> Option<SubscriptionEventNotifierBatch<'c, 'b>>

Maybe get a notifier for the given node ID and attribute ID.

This allows you to only sample when a user is listening.

Example
if let Some(mut notif) = notifier.notify_for((1, 123)) {
    notif.event(&my_event);
    notif.event(&my_other_event);
}
pub fn notify(&mut self, node_id: impl IntoNodeIdRef<'a>, event: &'b dyn Event)

Notify the subscription cache of a new event for the given node ID and attribute ID.

Arguments
  • node_id - The node ID or reference to node ID for the node emitting the event.
  • event - The event to notify the server of.