pub struct ContinuationPoint { /* private fields */ }Expand description
Representation of a dynamic continuation point. Each node manager may provide their own continuation point type, which is stored by the server. This wraps that value and provides interfaces to access it for a given node manager.
Implementations
Sourceimpl ContinuationPoint
impl ContinuationPoint
Sourcepub fn new<T>(item: Box<T>) -> ContinuationPoint
pub fn new<T>(item: Box<T>) -> ContinuationPoint
Create a new continuation point with item as content.
Sourcepub fn get<T>(&self) -> Option<&T>
pub fn get<T>(&self) -> Option<&T>
Retrieve the value of the continuation point.
This will return None if the stored value is not equal to the
given type. Most node managers should report an error if this happens.