pub struct MonitoredItem { /* private fields */ }Expand description
State of an active monitored item on the server.
Implementations
Sourceimpl MonitoredItem
impl MonitoredItem
Sourcepub fn has_last_value(&self) -> bool
pub fn has_last_value(&self) -> bool
Return true if this item has a stored last value.
Sourcepub fn is_reporting(&self) -> bool
pub fn is_reporting(&self) -> bool
Whether this monitored item is currently reporting new values.
Sourcepub fn is_sampling(&self) -> bool
pub fn is_sampling(&self) -> bool
Whether this monitored item is currently storing new values.
Sourcepub fn triggered_items(&self) -> &BTreeSet<u32>
pub fn triggered_items(&self) -> &BTreeSet<u32>
Items that are triggered by updates to this monitored item.
Sourcepub fn has_notifications(&self) -> bool
pub fn has_notifications(&self) -> bool
Whether this monitored item has enqueued notifications.
Sourcepub fn sampling_interval(&self) -> f64
pub fn sampling_interval(&self) -> f64
Sampling interval.
Sourcepub fn sampling_interval_as_time_delta(&self) -> TimeDelta
pub fn sampling_interval_as_time_delta(&self) -> TimeDelta
Get the sampling interval as a TimeDelta.
Sourcepub fn queue_size(&self) -> usize
pub fn queue_size(&self) -> usize
Current maximum queue size.
Sourcepub fn item_to_monitor(&self) -> &ParsedReadValueId
pub fn item_to_monitor(&self) -> &ParsedReadValueId
Item being monitored.
Sourcepub fn monitoring_mode(&self) -> MonitoringMode
pub fn monitoring_mode(&self) -> MonitoringMode
Current monitoring mode.
Sourcepub fn discard_oldest(&self) -> bool
pub fn discard_oldest(&self) -> bool
Whether oldest or newest values are discarded when the queue overflows.
Sourcepub fn client_handle(&self) -> u32
pub fn client_handle(&self) -> u32
Get the client defined handle for this monitored item.