pub struct OperationalLimits {Show 17 fields
pub max_nodes_per_translate_browse_paths_to_node_ids: usize,
pub max_nodes_per_read: usize,
pub max_nodes_per_write: usize,
pub max_nodes_per_method_call: usize,
pub max_nodes_per_browse: usize,
pub max_nodes_per_register_nodes: usize,
pub max_monitored_items_per_call: usize,
pub max_nodes_per_history_read_data: usize,
pub max_nodes_per_history_read_events: usize,
pub max_nodes_per_history_update: usize,
pub max_references_per_browse_node: usize,
pub max_node_descs_per_query: usize,
pub max_data_sets_query_return: usize,
pub max_references_query_return: usize,
pub max_nodes_per_node_management: usize,
pub max_references_per_references_management: usize,
pub max_subscriptions_per_call: usize,
}Expand description
Limits on service calls.
Fields
max_nodes_per_translate_browse_paths_to_node_ids: usizeMaximum number of nodes per translate browse paths to node IDs call.
max_nodes_per_read: usizeMaximum number of nodes per Read call.
max_nodes_per_write: usizeMaximum number of nodes per Write call.
max_nodes_per_method_call: usizeMaximum number of nodes per Call service call.
max_nodes_per_browse: usizeMaximum number of nodes per Browse call.
max_nodes_per_register_nodes: usizeMaximum number of nodes per RegisterNodes call.
max_monitored_items_per_call: usizeMaximum number of nodes per create/modify/delete monitored items call.
max_nodes_per_history_read_data: usizeMaximum number of nodes per history read call for data values.
max_nodes_per_history_read_events: usizeMaximum number of nodes per history read call for events.
max_nodes_per_history_update: usizeMaximum number of nodes per history update call.
max_references_per_browse_node: usizeMaximum number of references per node during browse.
max_node_descs_per_query: usizeMaximum number of node descriptions per query call.
max_data_sets_query_return: usizeMaximum number of data sets returned per node on query calls.
max_references_query_return: usizeMaximum number of references per data set on query calls.
max_nodes_per_node_management: usizeMaximum number of nodes per add/delete nodes call.
max_references_per_references_management: usizeMaximum number of references per add/delete references call.
max_subscriptions_per_call: usizeMaximum number of subscriptions per create/modify/delete subscriptions call.