pub struct ServerEndpoint {
pub path: String,
pub security_policy: String,
pub security_mode: String,
pub security_level: u8,
pub password_security_policy: Option<String>,
pub user_token_ids: BTreeSet<String>,
}Expand description
A configured server endpoint.
Fields
path: StringEndpoint path
security_policy: StringSecurity policy
security_mode: StringSecurity mode
security_level: u8Security level, higher being more secure
password_security_policy: Option<String>Password security policy when a client supplies a user name identity token
user_token_ids: BTreeSet<String>User tokens
Implementations
Sourceimpl ServerEndpoint
impl ServerEndpoint
Sourcepub fn new<T>(
path: T,
security_policy: SecurityPolicy,
security_mode: MessageSecurityMode,
user_token_ids: &[String],
) -> ServerEndpoint
pub fn new<T>( path: T, security_policy: SecurityPolicy, security_mode: MessageSecurityMode, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint.
Sourcepub fn new_none<T>(path: T, user_token_ids: &[String]) -> ServerEndpoint
pub fn new_none<T>(path: T, user_token_ids: &[String]) -> ServerEndpoint
Create a new unsecured server endpoint.
Sourcepub fn new_basic128rsa15_sign<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
👎Deprecated
pub fn new_basic128rsa15_sign<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with Basic128 signature.
Warning
This security mode is deprecated in the OPC-UA standard for being insecure.
Sourcepub fn new_basic128rsa15_sign_encrypt<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
👎Deprecated
pub fn new_basic128rsa15_sign_encrypt<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with Basic128 encryption.
Warning
This security mode is deprecated in the OPC-UA standard for being insecure.
Sourcepub fn new_basic256_sign<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
👎Deprecated
pub fn new_basic256_sign<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with Basic256 signature.
Warning
This security mode is deprecated in the OPC-UA standard for being insecure.
Sourcepub fn new_basic256_sign_encrypt<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
👎Deprecated
pub fn new_basic256_sign_encrypt<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with Basic256 encryption.
Warning
This security mode is deprecated in the OPC-UA standard for being insecure.
Sourcepub fn new_basic256sha256_sign<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
👎Deprecated
pub fn new_basic256sha256_sign<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with Basic256/Sha256 signing.
Warning
This security mode is deprecated in the OPC-UA standard for being insecure.
Sourcepub fn new_basic256sha256_sign_encrypt<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
pub fn new_basic256sha256_sign_encrypt<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with Basic256/Sha256 encryption.
Warning
This security mode is deprecated in the OPC-UA standard for being insecure.
Sourcepub fn new_aes128_sha256_rsaoaep_sign<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
pub fn new_aes128_sha256_rsaoaep_sign<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with AES128/SHA256 RSA-OAEP signing.
Sourcepub fn new_aes128_sha256_rsaoaep_sign_encrypt<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
pub fn new_aes128_sha256_rsaoaep_sign_encrypt<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with AES128/SHA256 RSA-OAEP encryption.
Sourcepub fn new_aes256_sha256_rsapss_sign<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
pub fn new_aes256_sha256_rsapss_sign<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with AES128/SHA256 RSA-PSS signing.
Sourcepub fn new_aes256_sha256_rsapss_sign_encrypt<T>(
path: T,
user_token_ids: &[String],
) -> ServerEndpoint
pub fn new_aes256_sha256_rsapss_sign_encrypt<T>( path: T, user_token_ids: &[String], ) -> ServerEndpoint
Create a new server endpoint with AES128/SHA256 RSA-PSS encryption.
Sourcepub fn validate(
&self,
id: &str,
user_tokens: &BTreeMap<String, ServerUserToken>,
) -> Result<(), Vec<String>>
pub fn validate( &self, id: &str, user_tokens: &BTreeMap<String, ServerUserToken>, ) -> Result<(), Vec<String>>
Validate the endpoint and return a list of validation errors.
Sourcepub fn security_policy(&self) -> SecurityPolicy
pub fn security_policy(&self) -> SecurityPolicy
Get the security policy of this endpoint.
Sourcepub fn message_security_mode(&self) -> MessageSecurityMode
pub fn message_security_mode(&self) -> MessageSecurityMode
Get the message security mode of this endpoint.
Sourcepub fn endpoint_url(&self, base_endpoint: &str) -> String
pub fn endpoint_url(&self, base_endpoint: &str) -> String
Get the URL of this endpoint, with base_endpoint as root.
Sourcepub fn password_security_policy(&self) -> SecurityPolicy
pub fn password_security_policy(&self) -> SecurityPolicy
Returns the effective password security policy for the endpoint. This is the explicitly set password security policy, or just the regular security policy.