ServerHandle

Struct ServerHandle 

pub struct ServerHandle { /* private fields */ }
Reference to a server instance containing tools to modify the server while it is running.

Implementations

Source

impl ServerHandle

pub fn info(&self) -> &Arc<ServerInfo>

Get a reference to the ServerInfo, containing configuration and other shared server data.

pub fn subscriptions(&self) -> &Arc<SubscriptionCache>

Get a reference to the subscription cache.

pub fn set_service_level(&self, sl: u8)

Set the service level, properly notifying subscribed clients of the change.

pub fn node_managers(&self) -> &NodeManagers

Get a reference to the node managers on the server.

pub fn session_manager(&self) -> &RwLock<RawRwLock, SessionManager>

Get a reference to the session manager, containing all currently active sessions.

pub fn type_tree(&self) -> &RwLock<RawRwLock, DefaultTypeTree>

Get a reference to the type tree, containing shared information about types in the server.

pub fn set_server_state(&self, state: ServerState)

Set the server state. Note that this does not do anything beyond just setting the state and notifying clients.

pub fn token(&self) -> &CancellationToken

Get the cancellation token.

pub fn cancel(&self)

Signal the server to stop.

pub fn get_namespace_index(&self, namespace: &str) -> Option<u16>

Shorthand for getting the index of a namespace defined in the global server type tree.

pub fn shutdown_after(&self, time: Duration, reason: impl Into<LocalizedText>)

Tell the server to stop after time has elapsed. This will update the SecondsTillShutdown variable on the server as needed.

pub fn add_reverse_connect_target(&self, target: ReverseConnectTargetConfig)

Add a reverse connect target to the server. If a target with the same ID has already been added, this does nothing.

pub fn remove_reverse_connect_target(&self, id: &str)

Remove a reverse connect target from the server. If the target does not exist, this does nothing.

This will not disconnect any existing connections to the target, only prevent new ones from being established.