Subscription

Struct Subscription 

pub struct Subscription { /* private fields */ }
A single subscription maintained by the server.

Implementations

Source

impl Subscription

pub fn len(&self) -> usize

Get the number of monitored items in this subscription.

pub fn is_empty(&self) -> bool

Return whether the subscription has no monitored items.

pub fn get(&self, id: &u32) -> Option<&MonitoredItem>

Get a reference to a monitored item managed by this subscription.

pub fn contains_key(&self, id: &u32) -> bool

Return whether the subscription contains the given monitored item ID.

pub fn items(&self) -> impl Iterator<Item = &MonitoredItem>

Iterate over the monitored items in the subscription.

pub fn set_resend_data(&mut self)

Set resend_data. The next publish request will send values for all monitored items, whether or not they have produced any new data.

pub fn notify_data_value(&mut self, id: &u32, value: DataValue, now: &DateTime)

Notify the given monitored item of a new data value.

pub fn notify_event( &mut self, id: &u32, event: &dyn Event, type_tree: &dyn TypeTree, )

Notify the given monitored item of a new event.

pub fn id(&self) -> u32

The ID of this subscription.

pub fn priority(&self) -> u8

The priority of this subscription.

pub fn publishing_interval(&self) -> Duration

The publishing interval of this subscription.

pub fn publishing_enabled(&self) -> bool

Whether publishing is enabled on this subscription.

pub fn max_queued_notifications(&self) -> usize

The maximum number of notification messages queued for this subscription.

pub fn max_notifications_per_publish(&self) -> usize

The maximum number of notifications per notification message for this subscription.

pub fn state(&self) -> SubscriptionState

The current state of the subscription.