SubscriptionLimits

Struct SubscriptionLimits 

pub struct SubscriptionLimits {
    pub max_subscriptions_per_session: usize,
    pub max_pending_publish_requests: usize,
    pub max_publish_requests_per_subscription: usize,
    pub min_sampling_interval_ms: f64,
    pub min_publishing_interval_ms: f64,
    pub max_keep_alive_count: u32,
    pub default_keep_alive_count: u32,
    pub max_monitored_items_per_sub: usize,
    pub max_monitored_item_queue_size: usize,
    pub max_lifetime_count: u32,
    pub max_notifications_per_publish: u64,
    pub max_queued_notifications: usize,
}
Subscription-related limits.

Fields

max_subscriptions_per_session: usize

Maximum number of subscriptions per session.

max_pending_publish_requests: usize

Maximum number of pending publish requests per session.

max_publish_requests_per_subscription: usize

Maximum number of publish requests per session, per subscription. The smallest of this and max_pending_publish_requests is used.

min_sampling_interval_ms: f64

Specifies the minimum sampling interval for this server in milliseconds.

min_publishing_interval_ms: f64

Specifies the minimum publishing interval for this server in milliseconds.

max_keep_alive_count: u32

Maximum value of KeepAliveCount

default_keep_alive_count: u32

Default value of KeepAliveCount, used if the client sets it to 0.

max_monitored_items_per_sub: usize

Maximum number of monitored items per subscription, 0 for no limit

max_monitored_item_queue_size: usize

Maximum number of values in a monitored item queue

max_lifetime_count: u32

Maximum lifetime count (3 times as large as max keep alive)

max_notifications_per_publish: u64

Maximum number of notifications per publish message.

max_queued_notifications: usize

Maximum number of queued notifications per subscription. 0 for unlimited.