EventField

Trait EventField 

pub trait EventField {
    // Required method
    fn get_value(
        &self,
        attribute_id: AttributeId,
        index_range: &NumericRange,
        remaining_path: &[QualifiedName],
    ) -> Variant;
}
Trait implemented by any type that can be a field in an event.

Required Methods

fn get_value( &self, attribute_id: AttributeId, index_range: &NumericRange, remaining_path: &[QualifiedName], ) -> Variant

Get the variant representation of this field, using the given index range.

Arguments
  • attribute_id - the attribute to get. Should be either NodeId or Value.
  • index_range - the range of the value to get.
  • remaining_path - the remaining path to the actual value to retrieve.

Implementations on Foreign Types

Source

impl<T> EventField for Option<T>
where T: EventField,

Source

fn get_value( &self, attribute_id: AttributeId, index_range: &NumericRange, remaining_path: &[QualifiedName], ) -> Variant

Source

impl<T> EventField for Vec<T>

Source

fn get_value( &self, attribute_id: AttributeId, index_range: &NumericRange, remaining_path: &[QualifiedName], ) -> Variant

Implementors

Source

impl EventField for NumericRange

Source

impl EventField for Variant

Source

impl EventField for AcknowledgeableConditionType

Source

impl EventField for AlarmConditionType

Source

impl EventField for AlarmGroupType

Source

impl EventField for AudioVariableType

Source

impl EventField for AuditActivateSessionEventType

Source

impl EventField for AuditAddNodesEventType

Source

impl EventField for AuditAddReferencesEventType

Source

impl EventField for AuditCancelEventType

Source

impl EventField for AuditCertificateDataMismatchEventType

Source

impl EventField for AuditCertificateEventType

Source

impl EventField for AuditCertificateExpiredEventType

Source

impl EventField for AuditCertificateInvalidEventType

Source

impl EventField for AuditCertificateMismatchEventType

Source

impl EventField for AuditCertificateRevokedEventType

Source

impl EventField for AuditCertificateUntrustedEventType

Source

impl EventField for AuditChannelEventType

Source

impl EventField for AuditClientEventType

Source

impl EventField for AuditClientUpdateMethodResultEventType

Source

impl EventField for AuditConditionAcknowledgeEventType

Source

impl EventField for AuditConditionCommentEventType

Source

impl EventField for AuditConditionConfirmEventType

Source

impl EventField for AuditConditionEnableEventType

Source

impl EventField for AuditConditionEventType

Source

impl EventField for AuditConditionOutOfServiceEventType

Source

impl EventField for AuditConditionResetEventType

Source

impl EventField for AuditConditionRespondEventType

Source

impl EventField for AuditConditionShelvingEventType

Source

impl EventField for AuditConditionSilenceEventType

Source

impl EventField for AuditConditionSuppressionEventType

Source

impl EventField for AuditCreateSessionEventType

Source

impl EventField for AuditDeleteNodesEventType

Source

impl EventField for AuditDeleteReferencesEventType

Source

impl EventField for AuditEventType

Source

impl EventField for AuditHistoryAnnotationUpdateEventType

Source

impl EventField for AuditHistoryAtTimeDeleteEventType

Source

impl EventField for AuditHistoryBulkInsertEventType

Source

impl EventField for AuditHistoryConfigurationChangeEventType

Source

impl EventField for AuditHistoryDeleteEventType

Source

impl EventField for AuditHistoryEventDeleteEventType

Source

impl EventField for AuditHistoryEventUpdateEventType

Source

impl EventField for AuditHistoryRawModifyDeleteEventType

Source

impl EventField for AuditHistoryUpdateEventType

Source

impl EventField for AuditHistoryValueUpdateEventType

Source

impl EventField for AuditNodeManagementEventType

Source

impl EventField for AuditOpenSecureChannelEventType

Source

impl EventField for AuditProgramTransitionEventType

Source

impl EventField for AuditSecurityEventType

Source

impl EventField for AuditSessionEventType

Source

impl EventField for AuditUpdateEventType

Source

impl EventField for AuditUpdateMethodEventType

Source

impl EventField for AuditUpdateStateEventType

Source

impl EventField for AuditUrlMismatchEventType

Source

impl EventField for AuditWriteUpdateEventType

Source

impl EventField for BaseModelChangeEventType

Source

impl EventField for CertificateExpirationAlarmType

Source

impl EventField for CertificateUpdateRequestedAuditEventType

Source

impl EventField for CertificateUpdatedAuditEventType

Source

impl EventField for ConditionType

Source

impl EventField for ConditionVariableType

Source

impl EventField for DeviceFailureEventType

Source

impl EventField for DialogConditionType

Source

impl EventField for DiscrepancyAlarmType

Source

impl EventField for DiscreteAlarmType

Source

impl EventField for EventQueueOverflowEventType

Source

impl EventField for ExclusiveDeviationAlarmType

Source

impl EventField for ExclusiveLevelAlarmType

Source

impl EventField for ExclusiveLimitAlarmType

Source

impl EventField for ExclusiveLimitStateMachineType

Source

impl EventField for ExclusiveRateOfChangeAlarmType

Source

impl EventField for FiniteStateMachineType

Source

impl EventField for FiniteStateVariableType

Source

impl EventField for FiniteTransitionVariableType

Source

impl EventField for GeneralModelChangeEventType

Source

impl EventField for InstrumentDiagnosticAlarmType

Source

impl EventField for KeyCredentialAuditEventType

Source

impl EventField for KeyCredentialDeletedAuditEventType

Source

impl EventField for KeyCredentialUpdatedAuditEventType

Source

impl EventField for LimitAlarmType

Source

impl EventField for NonExclusiveDeviationAlarmType

Source

impl EventField for NonExclusiveLevelAlarmType

Source

impl EventField for NonExclusiveLimitAlarmType

Source

impl EventField for NonExclusiveRateOfChangeAlarmType

Source

impl EventField for OffNormalAlarmType

Source

impl EventField for ProgramTransitionAuditEventType

Source

impl EventField for ProgramTransitionEventType

Source

impl EventField for ProgressEventType

Source

impl EventField for PubSubCommunicationFailureEventType

Source

impl EventField for PubSubStatusEventType

Source

impl EventField for PubSubTransportLimitsExceedEventType

Source

impl EventField for RefreshEndEventType

Source

impl EventField for RefreshRequiredEventType

Source

impl EventField for RefreshStartEventType

Source

impl EventField for RoleMappingRuleChangedAuditEventType

Source

impl EventField for SemanticChangeEventType

Source

impl EventField for ShelvedStateMachineType

Source

impl EventField for StateMachineType

Source

impl EventField for StateType

Source

impl EventField for StateVariableType

Source

impl EventField for SystemDiagnosticAlarmType

Source

impl EventField for SystemEventType

Source

impl EventField for SystemOffNormalAlarmType

Source

impl EventField for SystemStatusChangeEventType

Source

impl EventField for TransitionEventType

Source

impl EventField for TransitionType

Source

impl EventField for TransitionVariableType

Source

impl EventField for TripAlarmType

Source

impl EventField for TrustListOutOfDateAlarmType

Source

impl EventField for TrustListUpdateRequestedAuditEventType

Source

impl EventField for TrustListUpdatedAuditEventType

Source

impl EventField for TwoStateVariableType

Source

impl EventField for BaseEventType

Source

impl EventField for MethodEventField

Source

impl<T> EventField for T
where T: IntoVariant + Clone,