Structs
- Array
- An array is a vector of values with an optional number of dimensions. It is expected that the multi-dimensional array is valid, or it might not be encoded or decoded properly. The dimensions should match the number of values, or the array is invalid.
Functions
- values_
are_ of_ type - Check that all elements in the slice of arrays are the same type.