write_array

Function write_array 

pub fn write_array<S: Write, T: BinaryEncoder<T>>(
    stream: &mut S,
    values: &Option<Vec<T>>,
) -> EncodingResult<usize>
Write an array of the encoded type to stream, preserving distinction between null array and empty array