pub struct DecodingOptions {
pub client_offset: Duration,
pub max_message_size: usize,
pub max_chunk_count: usize,
pub max_string_length: usize,
pub max_byte_string_length: usize,
pub max_array_length: usize,
pub decoding_depth_gauge: Arc<Mutex<DepthGauge>>,
}Fields
client_offset: DurationTime offset between the client and the server, only used by the client when it’s configured to ignore time skew.
max_message_size: usizeMaximum size of a message in bytes. 0 means no limit.
max_chunk_count: usizeMaximum number of chunks. 0 means no limit.
max_string_length: usizeMaximum length in bytes (not chars!) of a string. 0 actually means 0, i.e. no string permitted
max_byte_string_length: usizeMaximum length in bytes of a byte string. 0 actually means 0, i.e. no byte string permitted
max_array_length: usizeMaximum number of array elements. 0 actually means 0, i.e. no array permitted
decoding_depth_gauge: Arc<Mutex<DepthGauge>>Decoding depth gauge is used to check for recursion
Implementations
Sourceimpl DecodingOptions
impl DecodingOptions
Sourcepub fn minimal() -> Self
pub fn minimal() -> Self
This can be useful for decoding extension objects where the payload is not expected to contain a large value.
pub fn depth_lock(&self) -> Result<DepthLock, StatusCode>