pub struct DepthGauge { /* private fields */ }Expand description
Depth gauge is used on potentially recursive structures like Variant & ExtensionObject during decoding to limit the depth the decoder will go before giving up.
Implementations
Sourceimpl DepthGauge
impl DepthGauge
Sourcepub fn new(max_depth: u64) -> DepthGauge
pub fn new(max_depth: u64) -> DepthGauge
Create a new depth gauge with specified max depth.
Sourcepub fn minimal() -> DepthGauge
pub fn minimal() -> DepthGauge
Create a minimal depth gauge with max depth of 1.