pub struct DepthLock { /* private fields */ }Expand description
Depth lock holds a reference on the depth gauge. The drop ensures impl that the reference is decremented even if there is a panic unwind.
Implementations