SimpleBinaryDecodable

Trait SimpleBinaryDecodable 

pub trait SimpleBinaryDecodable: Sized {
    // Required method
    fn decode<S>(
        stream: &mut S,
        decoding_options: &DecodingOptions,
    ) -> Result<Self, Error>
       where S: Read + ?Sized;
}
Trait for decoding a type that cannot contain any custom types from OPC UA binary. Used in some core modules to decode raw binary messages.

Required Methods

fn decode<S>( stream: &mut S, decoding_options: &DecodingOptions, ) -> Result<Self, Error>
where S: Read + ?Sized,

Decode Self from the byte stream.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl SimpleBinaryDecodable for bool

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<bool, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for f32

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<f32, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for f64

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<f64, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for i8

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<i8, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for i16

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<i16, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for i32

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<i32, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for i64

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<i64, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for u8

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<u8, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for u16

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<u16, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for u32

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<u32, Error>
where S: Read + ?Sized,

Source

impl SimpleBinaryDecodable for u64

Source

fn decode<S>( stream: &mut S, _decoding_options: &DecodingOptions, ) -> Result<u64, Error>
where S: Read + ?Sized,

Implementors

Source

impl SimpleBinaryDecodable for NumericRange

Source

impl SimpleBinaryDecodable for MessageChunk

Source

impl SimpleBinaryDecodable for MessageChunkHeader

Source

impl SimpleBinaryDecodable for AsymmetricSecurityHeader

Source

impl SimpleBinaryDecodable for SequenceHeader

Source

impl SimpleBinaryDecodable for SymmetricSecurityHeader

Source

impl SimpleBinaryDecodable for AcknowledgeMessage

Source

impl SimpleBinaryDecodable for ErrorMessage

Source

impl SimpleBinaryDecodable for HelloMessage

Source

impl SimpleBinaryDecodable for MessageHeader

Source

impl SimpleBinaryDecodable for ReverseHelloMessage

Source

impl SimpleBinaryDecodable for AccessLevelExType

Source

impl SimpleBinaryDecodable for AccessLevelType

Source

impl SimpleBinaryDecodable for AccessRestrictionType

Source

impl SimpleBinaryDecodable for AlarmMask

Source

impl SimpleBinaryDecodable for AttributeWriteMask

Source

impl SimpleBinaryDecodable for ByteString

Source

impl SimpleBinaryDecodable for DataSetFieldContentMask

Source

impl SimpleBinaryDecodable for DataSetFieldFlags

Source

impl SimpleBinaryDecodable for EventNotifierType

Source

impl SimpleBinaryDecodable for JsonDataSetMessageContentMask

Source

impl SimpleBinaryDecodable for JsonNetworkMessageContentMask

Source

impl SimpleBinaryDecodable for LldpSystemCapabilitiesMap

Source

impl SimpleBinaryDecodable for PasswordOptionsMask

Source

impl SimpleBinaryDecodable for PermissionType

Source

impl SimpleBinaryDecodable for PubSubConfigurationRefMask

Source

impl SimpleBinaryDecodable for StatusCode

Source

impl SimpleBinaryDecodable for TrustListValidationOptions

Source

impl SimpleBinaryDecodable for UAString

Source

impl SimpleBinaryDecodable for UadpDataSetMessageContentMask

Source

impl SimpleBinaryDecodable for UadpNetworkMessageContentMask

Source

impl SimpleBinaryDecodable for UserConfigurationMask