pub trait UaNullable {
// Provided method
fn is_ua_null(&self) -> bool { ... }
}Expand description
Trait implemented by OPC-UA types, indicating whether they are null or not, for use in encoding.
Provided Methods
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when being encoded in JSON and XML encodings.