IdentityCriteriaType

Enum IdentityCriteriaType 

#[repr(i32)]
pub enum IdentityCriteriaType { UserName = 1, Thumbprint = 2, Role = 3, GroupId = 4, Anonymous = 5, AuthenticatedUser = 6, Application = 7, X509Subject = 8, TrustedApplication = 9, }
https://reference.opcfoundation.org/v105/Core/docs/Part18/4.4.4

Variants



UserName = 1

The rule specifies a UserName from a UserNameIdentityToken.



Thumbprint = 2

The rule specifies the Thumbprint of a user or CA Certificate.



Role = 3

The rule is a Role specified in an Access Token.



GroupId = 4

The rule is a user group specified in the Access Token.



Anonymous = 5

The rule specifies Anonymous UserIdentityToken.



AuthenticatedUser = 6

The rule specifies any non Anonymous UserIdentityToken.



Application = 7

The rule specifies the combination of an application identity and an Anonymous UserIdentityToken.



X509Subject = 8

The rule specifies the X509 subject name of a user or CA Certificate.



TrustedApplication = 9

The rule specifies any trusted application that has been authenticated with a trusted ApplicationInstance Certificate.