pub enum ExtensionObjectEncoding {
None,
ByteString(ByteString),
XmlElement(XmlElement),
}Expand description
Enumeration that holds the kinds of encoding that an ExtensionObject data may be encoded with.
Variants
None
For an extension object with nothing encoded with it
ByteString(ByteString)
For an extension object with data encoded in a ByteString
XmlElement(XmlElement)
For an extension object with data encoded in an XML string