Module node_id

Module node_id 

Contains implementation of the OPC-UA NodeId type, which is used to identify nodes in the address space of an OPC-UA server.

Structs

NodeId
An identifier for a node in the address space of an OPC UA Server.
NodeIdError
Error returned from working with node IDs.
NodeIdRef
Cheap reference to a node ID of a specific type.

Enums

Identifier
The kind of identifier, numeric, string, guid or byte

Constants

IDENTIFIER_HASH_BYTE_STRING
Value used as discriminator when hashing byte string node IDs.
IDENTIFIER_HASH_GUID
Value used as discriminator when hashing Guid node IDs.
IDENTIFIER_HASH_NUMERIC
Value used as discriminator when hashing numeric node IDs.
IDENTIFIER_HASH_STRING
Value used as discriminator when hashing string node IDs.

Traits

IdentifierRef
Trait that indicates that a type can be used as a reference to an identifier. Contains a special hash method that includes the descriminator for the identifier variant, which means that it hashes to the same value as the equivalent identifier.
IntoNodeIdRef
Trait that allows converting a type into a NodeIdRef. This is used instead of Into to allow for simple function signatures.