pub struct BuildInfo {
pub product_uri: UAString,
pub manufacturer_name: UAString,
pub product_name: UAString,
pub software_version: UAString,
pub build_number: UAString,
pub build_date: DateTime,
}Fields
product_uri: UAStringmanufacturer_name: UAStringproduct_name: UAStringsoftware_version: UAStringbuild_number: UAStringbuild_date: DateTimeTrait Implementations
Sourceimpl BinaryEncoder<BuildInfo> for BuildInfo
impl BinaryEncoder<BuildInfo> for BuildInfo
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl MessageInfo for BuildInfo
impl MessageInfo for BuildInfo
impl StructuralPartialEq for BuildInfo