pub struct CallMethodRequest {
pub object_id: NodeId,
pub method_id: NodeId,
pub input_arguments: Option<Vec<Variant>>,
}Fields
object_id: NodeIdmethod_id: NodeIdinput_arguments: Option<Vec<Variant>>Trait Implementations
Sourceimpl BinaryEncoder<CallMethodRequest> for CallMethodRequest
impl BinaryEncoder<CallMethodRequest> for CallMethodRequest
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for CallMethodRequest
impl Clone for CallMethodRequest
Sourcefn clone(&self) -> CallMethodRequest
fn clone(&self) -> CallMethodRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CallMethodRequest
impl Debug for CallMethodRequest
Sourceimpl Into<CallMethodRequest> for (NodeId, NodeId, Option<Vec<Variant>>)
impl Into<CallMethodRequest> for (NodeId, NodeId, Option<Vec<Variant>>)
Sourcefn into(self) -> CallMethodRequest
fn into(self) -> CallMethodRequest
Converts this type into the (usually inferred) input type.
Sourceimpl MessageInfo for CallMethodRequest
impl MessageInfo for CallMethodRequest
Sourceimpl PartialEq for CallMethodRequest
impl PartialEq for CallMethodRequest
Sourcefn eq(&self, other: &CallMethodRequest) -> bool
fn eq(&self, other: &CallMethodRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CallMethodRequest