pub struct DataChangeNotification {
pub monitored_items: Option<Vec<MonitoredItemNotification>>,
pub diagnostic_infos: Option<Vec<DiagnosticInfo>>,
}Fields
monitored_items: Option<Vec<MonitoredItemNotification>>diagnostic_infos: Option<Vec<DiagnosticInfo>>Trait Implementations
Sourceimpl BinaryEncoder<DataChangeNotification> for DataChangeNotification
impl BinaryEncoder<DataChangeNotification> for DataChangeNotification
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for DataChangeNotification
impl Clone for DataChangeNotification
Sourcefn clone(&self) -> DataChangeNotification
fn clone(&self) -> DataChangeNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataChangeNotification
impl Debug for DataChangeNotification
Sourceimpl PartialEq for DataChangeNotification
impl PartialEq for DataChangeNotification
Sourcefn eq(&self, other: &DataChangeNotification) -> bool
fn eq(&self, other: &DataChangeNotification) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DataChangeNotification