pub struct DataSetMetaDataType {
pub namespaces: Option<Vec<UAString>>,
pub structure_data_types: Option<Vec<StructureDescription>>,
pub enum_data_types: Option<Vec<EnumDescription>>,
pub simple_data_types: Option<Vec<SimpleTypeDescription>>,
pub name: UAString,
pub description: LocalizedText,
pub fields: Option<Vec<FieldMetaData>>,
pub data_set_class_id: Guid,
pub configuration_version: ConfigurationVersionDataType,
}Fields
namespaces: Option<Vec<UAString>>structure_data_types: Option<Vec<StructureDescription>>enum_data_types: Option<Vec<EnumDescription>>simple_data_types: Option<Vec<SimpleTypeDescription>>name: UAStringdescription: LocalizedTextfields: Option<Vec<FieldMetaData>>data_set_class_id: Guidconfiguration_version: ConfigurationVersionDataTypeTrait Implementations
Sourceimpl BinaryEncoder<DataSetMetaDataType> for DataSetMetaDataType
impl BinaryEncoder<DataSetMetaDataType> for DataSetMetaDataType
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for DataSetMetaDataType
impl Clone for DataSetMetaDataType
Sourcefn clone(&self) -> DataSetMetaDataType
fn clone(&self) -> DataSetMetaDataType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataSetMetaDataType
impl Debug for DataSetMetaDataType
Sourceimpl<'de> Deserialize<'de> for DataSetMetaDataType
impl<'de> Deserialize<'de> for DataSetMetaDataType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DataSetMetaDataType
impl PartialEq for DataSetMetaDataType
Sourcefn eq(&self, other: &DataSetMetaDataType) -> bool
fn eq(&self, other: &DataSetMetaDataType) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DataSetMetaDataType
impl Serialize for DataSetMetaDataType
impl StructuralPartialEq for DataSetMetaDataType