pub struct DataTypeAttributes {
pub specified_attributes: u32,
pub display_name: LocalizedText,
pub description: LocalizedText,
pub write_mask: u32,
pub user_write_mask: u32,
pub is_abstract: bool,
}Fields
specified_attributes: u32display_name: LocalizedTextdescription: LocalizedTextwrite_mask: u32user_write_mask: u32is_abstract: boolTrait Implementations
Sourceimpl BinaryEncoder<DataTypeAttributes> for DataTypeAttributes
impl BinaryEncoder<DataTypeAttributes> for DataTypeAttributes
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for DataTypeAttributes
impl Clone for DataTypeAttributes
Sourcefn clone(&self) -> DataTypeAttributes
fn clone(&self) -> DataTypeAttributes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataTypeAttributes
impl Debug for DataTypeAttributes
Sourceimpl PartialEq for DataTypeAttributes
impl PartialEq for DataTypeAttributes
Sourcefn eq(&self, other: &DataTypeAttributes) -> bool
fn eq(&self, other: &DataTypeAttributes) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DataTypeAttributes