pub struct DeleteSubscriptionsRequest {
pub request_header: RequestHeader,
pub subscription_ids: Option<Vec<u32>>,
}Fields
request_header: RequestHeadersubscription_ids: Option<Vec<u32>>Trait Implementations
Sourceimpl BinaryEncoder<DeleteSubscriptionsRequest> for DeleteSubscriptionsRequest
impl BinaryEncoder<DeleteSubscriptionsRequest> for DeleteSubscriptionsRequest
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for DeleteSubscriptionsRequest
impl Clone for DeleteSubscriptionsRequest
Sourcefn clone(&self) -> DeleteSubscriptionsRequest
fn clone(&self) -> DeleteSubscriptionsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteSubscriptionsRequest
impl Debug for DeleteSubscriptionsRequest
Sourceimpl Into<SupportedMessage> for DeleteSubscriptionsRequest
impl Into<SupportedMessage> for DeleteSubscriptionsRequest
Sourcefn into(self) -> SupportedMessage
fn into(self) -> SupportedMessage
Converts this type into the (usually inferred) input type.
Sourceimpl PartialEq for DeleteSubscriptionsRequest
impl PartialEq for DeleteSubscriptionsRequest
Sourcefn eq(&self, other: &DeleteSubscriptionsRequest) -> bool
fn eq(&self, other: &DeleteSubscriptionsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeleteSubscriptionsRequest