pub struct FieldMetaData {
pub name: UAString,
pub description: LocalizedText,
pub field_flags: DataSetFieldFlags,
pub built_in_type: u8,
pub data_type: NodeId,
pub value_rank: i32,
pub array_dimensions: Option<Vec<u32>>,
pub max_string_length: u32,
pub data_set_field_id: Guid,
pub properties: Option<Vec<KeyValuePair>>,
}Fields
name: UAStringdescription: LocalizedTextfield_flags: DataSetFieldFlagsbuilt_in_type: u8data_type: NodeIdvalue_rank: i32array_dimensions: Option<Vec<u32>>max_string_length: u32data_set_field_id: Guidproperties: Option<Vec<KeyValuePair>>Trait Implementations
Sourceimpl BinaryEncoder<FieldMetaData> for FieldMetaData
impl BinaryEncoder<FieldMetaData> for FieldMetaData
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for FieldMetaData
impl Clone for FieldMetaData
Sourcefn clone(&self) -> FieldMetaData
fn clone(&self) -> FieldMetaData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FieldMetaData
impl Debug for FieldMetaData
Sourceimpl<'de> Deserialize<'de> for FieldMetaData
impl<'de> Deserialize<'de> for FieldMetaData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MessageInfo for FieldMetaData
impl MessageInfo for FieldMetaData
Sourceimpl PartialEq for FieldMetaData
impl PartialEq for FieldMetaData
Sourcefn eq(&self, other: &FieldMetaData) -> bool
fn eq(&self, other: &FieldMetaData) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FieldMetaData
impl Serialize for FieldMetaData
impl StructuralPartialEq for FieldMetaData