pub struct ReadValueId {
pub node_id: NodeId,
pub attribute_id: u32,
pub index_range: UAString,
pub data_encoding: QualifiedName,
}Fields
node_id: NodeIdattribute_id: u32index_range: UAStringdata_encoding: QualifiedNameTrait Implementations
Sourceimpl BinaryEncoder<ReadValueId> for ReadValueId
impl BinaryEncoder<ReadValueId> for ReadValueId
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for ReadValueId
impl Clone for ReadValueId
Sourcefn clone(&self) -> ReadValueId
fn clone(&self) -> ReadValueId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadValueId
impl Debug for ReadValueId
Sourceimpl<'de> Deserialize<'de> for ReadValueId
impl<'de> Deserialize<'de> for ReadValueId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> From<&'a NodeId> for ReadValueId
impl<'a> From<&'a NodeId> for ReadValueId
Sourceimpl From<NodeId> for ReadValueId
impl From<NodeId> for ReadValueId
Sourceimpl MessageInfo for ReadValueId
impl MessageInfo for ReadValueId
Sourceimpl PartialEq for ReadValueId
impl PartialEq for ReadValueId
Sourceimpl Serialize for ReadValueId
impl Serialize for ReadValueId
impl StructuralPartialEq for ReadValueId