pub struct ServerDiagnosticsSummaryDataType {
pub server_view_count: u32,
pub current_session_count: u32,
pub cumulated_session_count: u32,
pub security_rejected_session_count: u32,
pub rejected_session_count: u32,
pub session_timeout_count: u32,
pub session_abort_count: u32,
pub current_subscription_count: u32,
pub cumulated_subscription_count: u32,
pub publishing_interval_count: u32,
pub security_rejected_requests_count: u32,
pub rejected_requests_count: u32,
}Fields
server_view_count: u32current_session_count: u32cumulated_session_count: u32security_rejected_session_count: u32rejected_session_count: u32session_timeout_count: u32session_abort_count: u32current_subscription_count: u32cumulated_subscription_count: u32publishing_interval_count: u32security_rejected_requests_count: u32rejected_requests_count: u32Trait Implementations
Sourceimpl BinaryEncoder<ServerDiagnosticsSummaryDataType> for ServerDiagnosticsSummaryDataType
impl BinaryEncoder<ServerDiagnosticsSummaryDataType> for ServerDiagnosticsSummaryDataType
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for ServerDiagnosticsSummaryDataType
impl Clone for ServerDiagnosticsSummaryDataType
Sourcefn clone(&self) -> ServerDiagnosticsSummaryDataType
fn clone(&self) -> ServerDiagnosticsSummaryDataType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ServerDiagnosticsSummaryDataType
impl<'de> Deserialize<'de> for ServerDiagnosticsSummaryDataType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ServerDiagnosticsSummaryDataType
impl PartialEq for ServerDiagnosticsSummaryDataType
Sourcefn eq(&self, other: &ServerDiagnosticsSummaryDataType) -> bool
fn eq(&self, other: &ServerDiagnosticsSummaryDataType) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ServerDiagnosticsSummaryDataType