pub struct StructureDescription {
pub data_type_id: NodeId,
pub name: QualifiedName,
pub structure_definition: StructureDefinition,
}Fields
data_type_id: NodeIdname: QualifiedNamestructure_definition: StructureDefinitionTrait Implementations
Sourceimpl BinaryEncoder<StructureDescription> for StructureDescription
impl BinaryEncoder<StructureDescription> for StructureDescription
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for StructureDescription
impl Clone for StructureDescription
Sourcefn clone(&self) -> StructureDescription
fn clone(&self) -> StructureDescription
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructureDescription
impl Debug for StructureDescription
Sourceimpl<'de> Deserialize<'de> for StructureDescription
impl<'de> Deserialize<'de> for StructureDescription
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StructureDescription
impl PartialEq for StructureDescription
Sourcefn eq(&self, other: &StructureDescription) -> bool
fn eq(&self, other: &StructureDescription) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StructureDescription
impl Serialize for StructureDescription
impl StructuralPartialEq for StructureDescription