pub struct TransferSubscriptionsRequest {
pub request_header: RequestHeader,
pub subscription_ids: Option<Vec<u32>>,
pub send_initial_values: bool,
}Fields
request_header: RequestHeadersubscription_ids: Option<Vec<u32>>send_initial_values: boolTrait Implementations
Sourceimpl BinaryEncoder<TransferSubscriptionsRequest> for TransferSubscriptionsRequest
impl BinaryEncoder<TransferSubscriptionsRequest> for TransferSubscriptionsRequest
Sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
fn encode<S: Write>(&self, stream: &mut S) -> EncodingResult<usize>
Encodes the instance to the write stream.
Sourcefn decode<S: Read>(
stream: &mut S,
decoding_options: &DecodingOptions,
) -> EncodingResult<Self>
fn decode<S: Read>( stream: &mut S, decoding_options: &DecodingOptions, ) -> EncodingResult<Self>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.fn encode_to_vec(&self) -> Vec<u8> ⓘ
Sourceimpl Clone for TransferSubscriptionsRequest
impl Clone for TransferSubscriptionsRequest
Sourcefn clone(&self) -> TransferSubscriptionsRequest
fn clone(&self) -> TransferSubscriptionsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferSubscriptionsRequest
impl Debug for TransferSubscriptionsRequest
Sourceimpl Into<SupportedMessage> for TransferSubscriptionsRequest
impl Into<SupportedMessage> for TransferSubscriptionsRequest
Sourcefn into(self) -> SupportedMessage
fn into(self) -> SupportedMessage
Converts this type into the (usually inferred) input type.
Sourceimpl PartialEq for TransferSubscriptionsRequest
impl PartialEq for TransferSubscriptionsRequest
Sourcefn eq(&self, other: &TransferSubscriptionsRequest) -> bool
fn eq(&self, other: &TransferSubscriptionsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TransferSubscriptionsRequest