Module status_code

Module status_code 

Implementation of OPC UA status codes.

See OPC-UA Part 4, part 7.34.1

Structs

StatusCode
Wrapper around an OPC-UA status code, with utilities for displaying, parsing, and reading.

Enums

StatusCodeInfoType
Whether the status code represents a data value or something else.
StatusCodeLimit
Limit bits on a status code.
StatusCodeSeverity
Severity of a status code.
StatusCodeValidationError
Error returned on status code validation failure.
StatusCodeValueType
The type of data value
SubStatusCode
The category of a status code.