pub struct AccessLevelExType(/* private fields */);Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part3/8.58
Implementations
Sourceimpl AccessLevelExType
impl AccessLevelExType
pub const CurrentRead: AccessLevelExType
pub const CurrentWrite: AccessLevelExType
pub const HistoryRead: AccessLevelExType
pub const HistoryWrite: AccessLevelExType
pub const SemanticChange: AccessLevelExType
pub const StatusWrite: AccessLevelExType
pub const TimestampWrite: AccessLevelExType
pub const NonatomicRead: AccessLevelExType
pub const NonatomicWrite: AccessLevelExType
pub const WriteFullArrayOnly: AccessLevelExType
pub const NoSubDataTypes: AccessLevelExType
pub const NonVolatile: AccessLevelExType
pub const Constant: AccessLevelExType
Sourceimpl AccessLevelExType
impl AccessLevelExType
Sourcepub const fn empty() -> AccessLevelExType
pub const fn empty() -> AccessLevelExType
Get a flags value with all bits unset.
Sourcepub const fn all() -> AccessLevelExType
pub const fn all() -> AccessLevelExType
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<AccessLevelExType>
pub const fn from_bits(bits: i32) -> Option<AccessLevelExType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> AccessLevelExType
pub const fn from_bits_truncate(bits: i32) -> AccessLevelExType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> AccessLevelExType
pub const fn from_bits_retain(bits: i32) -> AccessLevelExType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AccessLevelExType>
pub fn from_name(name: &str) -> Option<AccessLevelExType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AccessLevelExType) -> bool
pub const fn intersects(&self, other: AccessLevelExType) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AccessLevelExType) -> bool
pub const fn contains(&self, other: AccessLevelExType) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AccessLevelExType)
pub fn insert(&mut self, other: AccessLevelExType)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AccessLevelExType)
pub fn remove(&mut self, other: AccessLevelExType)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AccessLevelExType)
pub fn toggle(&mut self, other: AccessLevelExType)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AccessLevelExType, value: bool)
pub fn set(&mut self, other: AccessLevelExType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AccessLevelExType) -> AccessLevelExType
pub const fn intersection(self, other: AccessLevelExType) -> AccessLevelExType
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: AccessLevelExType) -> AccessLevelExType
pub const fn union(self, other: AccessLevelExType) -> AccessLevelExType
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: AccessLevelExType) -> AccessLevelExType
pub const fn difference(self, other: AccessLevelExType) -> AccessLevelExType
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AccessLevelExType,
) -> AccessLevelExType
pub const fn symmetric_difference( self, other: AccessLevelExType, ) -> AccessLevelExType
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AccessLevelExType
pub const fn complement(self) -> AccessLevelExType
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AccessLevelExType
impl AccessLevelExType
Sourcepub const fn iter(&self) -> Iter<AccessLevelExType> ⓘ
pub const fn iter(&self) -> Iter<AccessLevelExType> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AccessLevelExType> ⓘ
pub const fn iter_names(&self) -> IterNames<AccessLevelExType> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.