pub struct AccessLevelType(/* private fields */);Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part3/8.57
Implementations
Sourceimpl AccessLevelType
impl AccessLevelType
pub const CurrentRead: AccessLevelType
pub const CurrentWrite: AccessLevelType
pub const HistoryRead: AccessLevelType
pub const HistoryWrite: AccessLevelType
pub const SemanticChange: AccessLevelType
pub const StatusWrite: AccessLevelType
pub const TimestampWrite: AccessLevelType
Sourceimpl AccessLevelType
impl AccessLevelType
Sourcepub const fn empty() -> AccessLevelType
pub const fn empty() -> AccessLevelType
Get a flags value with all bits unset.
Sourcepub const fn all() -> AccessLevelType
pub const fn all() -> AccessLevelType
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<AccessLevelType>
pub const fn from_bits(bits: u8) -> Option<AccessLevelType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> AccessLevelType
pub const fn from_bits_truncate(bits: u8) -> AccessLevelType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> AccessLevelType
pub const fn from_bits_retain(bits: u8) -> AccessLevelType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AccessLevelType>
pub fn from_name(name: &str) -> Option<AccessLevelType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AccessLevelType) -> bool
pub const fn intersects(&self, other: AccessLevelType) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AccessLevelType) -> bool
pub const fn contains(&self, other: AccessLevelType) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: AccessLevelType)
pub fn insert(&mut self, other: AccessLevelType)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: AccessLevelType)
pub fn remove(&mut self, other: AccessLevelType)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AccessLevelType)
pub fn toggle(&mut self, other: AccessLevelType)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AccessLevelType, value: bool)
pub fn set(&mut self, other: AccessLevelType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AccessLevelType) -> AccessLevelType
pub const fn intersection(self, other: AccessLevelType) -> AccessLevelType
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: AccessLevelType) -> AccessLevelType
pub const fn union(self, other: AccessLevelType) -> AccessLevelType
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: AccessLevelType) -> AccessLevelType
pub const fn difference(self, other: AccessLevelType) -> AccessLevelType
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AccessLevelType,
) -> AccessLevelType
pub const fn symmetric_difference( self, other: AccessLevelType, ) -> AccessLevelType
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AccessLevelType
pub const fn complement(self) -> AccessLevelType
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AccessLevelType
impl AccessLevelType
Sourcepub const fn iter(&self) -> Iter<AccessLevelType> ⓘ
pub const fn iter(&self) -> Iter<AccessLevelType> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AccessLevelType> ⓘ
pub const fn iter_names(&self) -> IterNames<AccessLevelType> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.