pub struct AlarmMask(/* private fields */);Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part9/8.3
Implementations
Sourceimpl AlarmMask
impl AlarmMask
pub const Active: AlarmMask
pub const Unacknowledged: AlarmMask
pub const Unconfirmed: AlarmMask
Sourceimpl AlarmMask
impl AlarmMask
Sourcepub const fn bits(&self) -> i16
pub const fn bits(&self) -> i16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i16) -> Option<AlarmMask>
pub const fn from_bits(bits: i16) -> Option<AlarmMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i16) -> AlarmMask
pub const fn from_bits_truncate(bits: i16) -> AlarmMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i16) -> AlarmMask
pub const fn from_bits_retain(bits: i16) -> AlarmMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AlarmMask>
pub fn from_name(name: &str) -> Option<AlarmMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AlarmMask) -> bool
pub const fn intersects(&self, other: AlarmMask) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: AlarmMask) -> bool
pub const fn contains(&self, other: AlarmMask) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: AlarmMask)
pub fn remove(&mut self, other: AlarmMask)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AlarmMask)
pub fn toggle(&mut self, other: AlarmMask)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: AlarmMask, value: bool)
pub fn set(&mut self, other: AlarmMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AlarmMask) -> AlarmMask
pub const fn intersection(self, other: AlarmMask) -> AlarmMask
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: AlarmMask) -> AlarmMask
pub const fn union(self, other: AlarmMask) -> AlarmMask
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: AlarmMask) -> AlarmMask
pub const fn difference(self, other: AlarmMask) -> AlarmMask
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: AlarmMask) -> AlarmMask
pub const fn symmetric_difference(self, other: AlarmMask) -> AlarmMask
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> AlarmMask
pub const fn complement(self) -> AlarmMask
The bitwise negation (!) of the bits in a flags value, truncating the result.