pub struct BrowseRequest {
pub request_header: RequestHeader,
pub view: ViewDescription,
pub requested_max_references_per_node: u32,
pub nodes_to_browse: Option<Vec<BrowseDescription>>,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part4/5.9.2/#5.9.2.2
Fields
request_header: RequestHeaderview: ViewDescriptionrequested_max_references_per_node: u32nodes_to_browse: Option<Vec<BrowseDescription>>Trait Implementations
Sourceimpl BinaryDecodable for BrowseRequest
impl BinaryDecodable for BrowseRequest
Sourcefn decode<S>(stream: &mut S, ctx: &Context<'_>) -> Result<BrowseRequest, Error>
fn decode<S>(stream: &mut S, ctx: &Context<'_>) -> Result<BrowseRequest, Error>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for BrowseRequest
impl BinaryEncodable for BrowseRequest
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
fn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for BrowseRequest
impl Clone for BrowseRequest
Sourcefn clone(&self) -> BrowseRequest
fn clone(&self) -> BrowseRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowseRequest
impl Debug for BrowseRequest
Sourceimpl Default for BrowseRequest
impl Default for BrowseRequest
Sourcefn default() -> BrowseRequest
fn default() -> BrowseRequest
Returns the “default value” for a type. Read more
Sourceimpl From<BrowseRequest> for RequestMessage
impl From<BrowseRequest> for RequestMessage
Sourcefn from(value: BrowseRequest) -> RequestMessage
fn from(value: BrowseRequest) -> RequestMessage
Converts to this type from the input type.
Sourceimpl JsonDecodable for BrowseRequest
impl JsonDecodable for BrowseRequest
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<BrowseRequest, Error>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<BrowseRequest, Error>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for BrowseRequest
impl JsonEncodable for BrowseRequest
Sourceimpl MessageInfo for BrowseRequest
impl MessageInfo for BrowseRequest
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl PartialEq for BrowseRequest
impl PartialEq for BrowseRequest
Sourceimpl UaNullable for BrowseRequest
impl UaNullable for BrowseRequest
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for BrowseRequest
impl XmlDecodable for BrowseRequest
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<BrowseRequest, Error>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<BrowseRequest, Error>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for BrowseRequest
impl XmlEncodable for BrowseRequest
Sourceimpl XmlType for BrowseRequest
impl XmlType for BrowseRequest
impl StructuralPartialEq for BrowseRequest