pub struct DataSetFieldContentMask(/* private fields */);Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part14/6.2.4/#6.2.4.2
Implementations
Sourceimpl DataSetFieldContentMask
impl DataSetFieldContentMask
pub const StatusCode: DataSetFieldContentMask
pub const SourceTimestamp: DataSetFieldContentMask
pub const ServerTimestamp: DataSetFieldContentMask
pub const SourcePicoSeconds: DataSetFieldContentMask
pub const ServerPicoSeconds: DataSetFieldContentMask
pub const RawData: DataSetFieldContentMask
Sourceimpl DataSetFieldContentMask
impl DataSetFieldContentMask
Sourcepub const fn empty() -> DataSetFieldContentMask
pub const fn empty() -> DataSetFieldContentMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> DataSetFieldContentMask
pub const fn all() -> DataSetFieldContentMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<DataSetFieldContentMask>
pub const fn from_bits(bits: i32) -> Option<DataSetFieldContentMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> DataSetFieldContentMask
pub const fn from_bits_truncate(bits: i32) -> DataSetFieldContentMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> DataSetFieldContentMask
pub const fn from_bits_retain(bits: i32) -> DataSetFieldContentMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DataSetFieldContentMask>
pub fn from_name(name: &str) -> Option<DataSetFieldContentMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DataSetFieldContentMask) -> bool
pub const fn intersects(&self, other: DataSetFieldContentMask) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: DataSetFieldContentMask) -> bool
pub const fn contains(&self, other: DataSetFieldContentMask) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: DataSetFieldContentMask)
pub fn insert(&mut self, other: DataSetFieldContentMask)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: DataSetFieldContentMask)
pub fn remove(&mut self, other: DataSetFieldContentMask)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DataSetFieldContentMask)
pub fn toggle(&mut self, other: DataSetFieldContentMask)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: DataSetFieldContentMask, value: bool)
pub fn set(&mut self, other: DataSetFieldContentMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DataSetFieldContentMask,
) -> DataSetFieldContentMask
pub const fn intersection( self, other: DataSetFieldContentMask, ) -> DataSetFieldContentMask
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(
self,
other: DataSetFieldContentMask,
) -> DataSetFieldContentMask
pub const fn union( self, other: DataSetFieldContentMask, ) -> DataSetFieldContentMask
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: DataSetFieldContentMask,
) -> DataSetFieldContentMask
pub const fn difference( self, other: DataSetFieldContentMask, ) -> DataSetFieldContentMask
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DataSetFieldContentMask,
) -> DataSetFieldContentMask
pub const fn symmetric_difference( self, other: DataSetFieldContentMask, ) -> DataSetFieldContentMask
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> DataSetFieldContentMask
pub const fn complement(self) -> DataSetFieldContentMask
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DataSetFieldContentMask
impl DataSetFieldContentMask
Sourcepub const fn iter(&self) -> Iter<DataSetFieldContentMask> ⓘ
pub const fn iter(&self) -> Iter<DataSetFieldContentMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DataSetFieldContentMask> ⓘ
pub const fn iter_names(&self) -> IterNames<DataSetFieldContentMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.