pub struct DeleteNodesItem {
pub node_id: NodeId,
pub delete_target_references: bool,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part5/12.3.6
Fields
node_id: NodeIddelete_target_references: boolTrait Implementations
Sourceimpl BinaryDecodable for DeleteNodesItem
impl BinaryDecodable for DeleteNodesItem
Sourcefn decode<S>(
stream: &mut S,
ctx: &Context<'_>,
) -> Result<DeleteNodesItem, Error>
fn decode<S>( stream: &mut S, ctx: &Context<'_>, ) -> Result<DeleteNodesItem, Error>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for DeleteNodesItem
impl BinaryEncodable for DeleteNodesItem
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
fn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for DeleteNodesItem
impl Clone for DeleteNodesItem
Sourcefn clone(&self) -> DeleteNodesItem
fn clone(&self) -> DeleteNodesItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteNodesItem
impl Debug for DeleteNodesItem
Sourceimpl Default for DeleteNodesItem
impl Default for DeleteNodesItem
Sourcefn default() -> DeleteNodesItem
fn default() -> DeleteNodesItem
Returns the “default value” for a type. Read more
Sourceimpl JsonDecodable for DeleteNodesItem
impl JsonDecodable for DeleteNodesItem
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<DeleteNodesItem, Error>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<DeleteNodesItem, Error>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for DeleteNodesItem
impl JsonEncodable for DeleteNodesItem
Sourceimpl MessageInfo for DeleteNodesItem
impl MessageInfo for DeleteNodesItem
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl PartialEq for DeleteNodesItem
impl PartialEq for DeleteNodesItem
Sourceimpl UaNullable for DeleteNodesItem
impl UaNullable for DeleteNodesItem
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for DeleteNodesItem
impl XmlDecodable for DeleteNodesItem
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<DeleteNodesItem, Error>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<DeleteNodesItem, Error>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for DeleteNodesItem
impl XmlEncodable for DeleteNodesItem
Sourceimpl XmlType for DeleteNodesItem
impl XmlType for DeleteNodesItem
impl StructuralPartialEq for DeleteNodesItem