pub struct FindServersResponse {
pub response_header: ResponseHeader,
pub servers: Option<Vec<ApplicationDescription>>,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part4/5.5.2/#5.5.2.2
Fields
response_header: ResponseHeaderservers: Option<Vec<ApplicationDescription>>Trait Implementations
Sourceimpl BinaryDecodable for FindServersResponse
impl BinaryDecodable for FindServersResponse
Sourcefn decode<S>(
stream: &mut S,
ctx: &Context<'_>,
) -> Result<FindServersResponse, Error>
fn decode<S>( stream: &mut S, ctx: &Context<'_>, ) -> Result<FindServersResponse, Error>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for FindServersResponse
impl BinaryEncodable for FindServersResponse
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
fn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for FindServersResponse
impl Clone for FindServersResponse
Sourcefn clone(&self) -> FindServersResponse
fn clone(&self) -> FindServersResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FindServersResponse
impl Debug for FindServersResponse
Sourceimpl Default for FindServersResponse
impl Default for FindServersResponse
Sourcefn default() -> FindServersResponse
fn default() -> FindServersResponse
Returns the “default value” for a type. Read more
Sourceimpl From<FindServersResponse> for ResponseMessage
impl From<FindServersResponse> for ResponseMessage
Sourcefn from(value: FindServersResponse) -> ResponseMessage
fn from(value: FindServersResponse) -> ResponseMessage
Converts to this type from the input type.
Sourceimpl JsonDecodable for FindServersResponse
impl JsonDecodable for FindServersResponse
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<FindServersResponse, Error>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<FindServersResponse, Error>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for FindServersResponse
impl JsonEncodable for FindServersResponse
Sourceimpl MessageInfo for FindServersResponse
impl MessageInfo for FindServersResponse
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl PartialEq for FindServersResponse
impl PartialEq for FindServersResponse
Sourceimpl UaNullable for FindServersResponse
impl UaNullable for FindServersResponse
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for FindServersResponse
impl XmlDecodable for FindServersResponse
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<FindServersResponse, Error>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<FindServersResponse, Error>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for FindServersResponse
impl XmlEncodable for FindServersResponse
Sourceimpl XmlType for FindServersResponse
impl XmlType for FindServersResponse
impl StructuralPartialEq for FindServersResponse