pub struct GuidRef<'a>(pub &'a [u8; 16]);Expand description
Reference to a Guid that can be created without allocating a Guid object. Used when comparing with NodeIds, to distinguish from the generic ByteString case.
Tuple Fields
0: &'a [u8; 16]Trait Implementations
Sourceimpl IdentifierRef for GuidRef<'_>
impl IdentifierRef for GuidRef<'_>
Sourcefn hash_as_identifier<H>(&self, state: &mut H)where
H: Hasher,
fn hash_as_identifier<H>(&self, state: &mut H)where
H: Hasher,
Hash the value as if it was in an identifier. This must result
in the same hash as the equivalent identifier.
Sourceimpl PartialEq<Identifier> for GuidRef<'_>
impl PartialEq<Identifier> for GuidRef<'_>