pub struct JsonActionResponderMessage {
pub message_id: UAString,
pub message_type: UAString,
pub publisher_id: UAString,
pub timestamp: DateTime,
pub connection: PubSubConnectionDataType,
}Fields
message_id: UAStringmessage_type: UAStringpublisher_id: UAStringtimestamp: DateTimeconnection: PubSubConnectionDataTypeTrait Implementations
Sourceimpl BinaryDecodable for JsonActionResponderMessage
impl BinaryDecodable for JsonActionResponderMessage
Sourcefn decode<S>(
stream: &mut S,
ctx: &Context<'_>,
) -> Result<JsonActionResponderMessage, Error>
fn decode<S>( stream: &mut S, ctx: &Context<'_>, ) -> Result<JsonActionResponderMessage, Error>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for JsonActionResponderMessage
impl BinaryEncodable for JsonActionResponderMessage
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
fn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for JsonActionResponderMessage
impl Clone for JsonActionResponderMessage
Sourcefn clone(&self) -> JsonActionResponderMessage
fn clone(&self) -> JsonActionResponderMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonActionResponderMessage
impl Debug for JsonActionResponderMessage
Sourceimpl Default for JsonActionResponderMessage
impl Default for JsonActionResponderMessage
Sourcefn default() -> JsonActionResponderMessage
fn default() -> JsonActionResponderMessage
Returns the “default value” for a type. Read more
Sourceimpl JsonDecodable for JsonActionResponderMessage
impl JsonDecodable for JsonActionResponderMessage
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<JsonActionResponderMessage, Error>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<JsonActionResponderMessage, Error>
Decode Self from a JSON stream.
Sourceimpl UaNullable for JsonActionResponderMessage
impl UaNullable for JsonActionResponderMessage
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for JsonActionResponderMessage
impl XmlDecodable for JsonActionResponderMessage
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<JsonActionResponderMessage, Error>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<JsonActionResponderMessage, Error>
Decode a value from an XML stream.
Sourceimpl XmlType for JsonActionResponderMessage
impl XmlType for JsonActionResponderMessage
impl StructuralPartialEq for JsonActionResponderMessage