pub struct NodeClassMask(/* private fields */);Expand description
Bitmask for node classes.
Implementations
Sourceimpl NodeClassMask
impl NodeClassMask
Sourcepub const OBJECT: NodeClassMask
pub const OBJECT: NodeClassMask
Object node class.
Sourcepub const VARIABLE: NodeClassMask
pub const VARIABLE: NodeClassMask
Variable node class.
Sourcepub const METHOD: NodeClassMask
pub const METHOD: NodeClassMask
Method node class.
Sourcepub const OBJECT_TYPE: NodeClassMask
pub const OBJECT_TYPE: NodeClassMask
Object type node class.
Sourcepub const VARIABLE_TYPE: NodeClassMask
pub const VARIABLE_TYPE: NodeClassMask
Variable type node class.
Sourcepub const REFERENCE_TYPE: NodeClassMask
pub const REFERENCE_TYPE: NodeClassMask
Reference type node class.
Sourcepub const DATA_TYPE: NodeClassMask
pub const DATA_TYPE: NodeClassMask
Data type node class.
Sourcepub const VIEW: NodeClassMask
pub const VIEW: NodeClassMask
View node class.
Sourceimpl NodeClassMask
impl NodeClassMask
Sourcepub const fn empty() -> NodeClassMask
pub const fn empty() -> NodeClassMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> NodeClassMask
pub const fn all() -> NodeClassMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<NodeClassMask>
pub const fn from_bits(bits: u32) -> Option<NodeClassMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> NodeClassMask
pub const fn from_bits_truncate(bits: u32) -> NodeClassMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> NodeClassMask
pub const fn from_bits_retain(bits: u32) -> NodeClassMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<NodeClassMask>
pub fn from_name(name: &str) -> Option<NodeClassMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: NodeClassMask) -> bool
pub const fn intersects(&self, other: NodeClassMask) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: NodeClassMask) -> bool
pub const fn contains(&self, other: NodeClassMask) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: NodeClassMask)
pub fn insert(&mut self, other: NodeClassMask)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: NodeClassMask)
pub fn remove(&mut self, other: NodeClassMask)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: NodeClassMask)
pub fn toggle(&mut self, other: NodeClassMask)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: NodeClassMask, value: bool)
pub fn set(&mut self, other: NodeClassMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: NodeClassMask) -> NodeClassMask
pub const fn intersection(self, other: NodeClassMask) -> NodeClassMask
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: NodeClassMask) -> NodeClassMask
pub const fn union(self, other: NodeClassMask) -> NodeClassMask
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: NodeClassMask) -> NodeClassMask
pub const fn difference(self, other: NodeClassMask) -> NodeClassMask
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: NodeClassMask) -> NodeClassMask
pub const fn symmetric_difference(self, other: NodeClassMask) -> NodeClassMask
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> NodeClassMask
pub const fn complement(self) -> NodeClassMask
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl NodeClassMask
impl NodeClassMask
Sourcepub const fn iter(&self) -> Iter<NodeClassMask> ⓘ
pub const fn iter(&self) -> Iter<NodeClassMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<NodeClassMask> ⓘ
pub const fn iter_names(&self) -> IterNames<NodeClassMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.