PlaceholderEventField

Struct PlaceholderEventField 

pub struct PlaceholderEventField<T> { /* private fields */ }
Struct for an event field placeholder, i.e. a dynamic list of fields.

Implementations

Source

impl<T> PlaceholderEventField<T>

pub fn new() -> PlaceholderEventField<T>

Create a new empty placeholder field.

pub fn get_field(&self, name: &QualifiedName) -> Option<&T>

Get the field given by name.

pub fn get_field_mut(&mut self, name: &QualifiedName) -> Option<&mut T>

Get a mutable reference to the field given by name.

pub fn remove_field(&mut self, name: &QualifiedName) -> Option<T>

Remove the field given by name.

pub fn insert_field(&mut self, name: QualifiedName, field: T) -> Option<T>

Insert field with key name.

pub fn items_mut(&mut self) -> &mut HashMap<QualifiedName, T>

Get a mutable reference to the inner items map.

pub fn items(&self) -> &HashMap<QualifiedName, T>

Get a reference to the inner items map.

Source

impl<T> PlaceholderEventField<T>
where T: EventField,

pub fn try_get_value( &self, key: &QualifiedName, attribute_id: AttributeId, index_range: &NumericRange, remaining_path: &[QualifiedName], ) -> Option<Variant>

Try to get the inner event value given by key.