pub struct PubSubConfigurationRefMask(/* private fields */);Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part14/9.1.3/#9.1.3.7.2
Implementations
Sourceimpl PubSubConfigurationRefMask
impl PubSubConfigurationRefMask
pub const ElementAdd: PubSubConfigurationRefMask
pub const ElementMatch: PubSubConfigurationRefMask
pub const ElementModify: PubSubConfigurationRefMask
pub const ElementRemove: PubSubConfigurationRefMask
pub const ReferenceWriter: PubSubConfigurationRefMask
pub const ReferenceReader: PubSubConfigurationRefMask
pub const ReferenceWriterGroup: PubSubConfigurationRefMask
pub const ReferenceReaderGroup: PubSubConfigurationRefMask
pub const ReferenceConnection: PubSubConfigurationRefMask
pub const ReferencePubDataset: PubSubConfigurationRefMask
pub const ReferenceSubDataset: PubSubConfigurationRefMask
pub const ReferenceSecurityGroup: PubSubConfigurationRefMask
pub const ReferencePushTarget: PubSubConfigurationRefMask
Sourceimpl PubSubConfigurationRefMask
impl PubSubConfigurationRefMask
Sourcepub const fn empty() -> PubSubConfigurationRefMask
pub const fn empty() -> PubSubConfigurationRefMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> PubSubConfigurationRefMask
pub const fn all() -> PubSubConfigurationRefMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<PubSubConfigurationRefMask>
pub const fn from_bits(bits: i32) -> Option<PubSubConfigurationRefMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> PubSubConfigurationRefMask
pub const fn from_bits_truncate(bits: i32) -> PubSubConfigurationRefMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> PubSubConfigurationRefMask
pub const fn from_bits_retain(bits: i32) -> PubSubConfigurationRefMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<PubSubConfigurationRefMask>
pub fn from_name(name: &str) -> Option<PubSubConfigurationRefMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: PubSubConfigurationRefMask) -> bool
pub const fn intersects(&self, other: PubSubConfigurationRefMask) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: PubSubConfigurationRefMask) -> bool
pub const fn contains(&self, other: PubSubConfigurationRefMask) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: PubSubConfigurationRefMask)
pub fn insert(&mut self, other: PubSubConfigurationRefMask)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: PubSubConfigurationRefMask)
pub fn remove(&mut self, other: PubSubConfigurationRefMask)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: PubSubConfigurationRefMask)
pub fn toggle(&mut self, other: PubSubConfigurationRefMask)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: PubSubConfigurationRefMask, value: bool)
pub fn set(&mut self, other: PubSubConfigurationRefMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: PubSubConfigurationRefMask,
) -> PubSubConfigurationRefMask
pub const fn intersection( self, other: PubSubConfigurationRefMask, ) -> PubSubConfigurationRefMask
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(
self,
other: PubSubConfigurationRefMask,
) -> PubSubConfigurationRefMask
pub const fn union( self, other: PubSubConfigurationRefMask, ) -> PubSubConfigurationRefMask
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: PubSubConfigurationRefMask,
) -> PubSubConfigurationRefMask
pub const fn difference( self, other: PubSubConfigurationRefMask, ) -> PubSubConfigurationRefMask
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: PubSubConfigurationRefMask,
) -> PubSubConfigurationRefMask
pub const fn symmetric_difference( self, other: PubSubConfigurationRefMask, ) -> PubSubConfigurationRefMask
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> PubSubConfigurationRefMask
pub const fn complement(self) -> PubSubConfigurationRefMask
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl PubSubConfigurationRefMask
impl PubSubConfigurationRefMask
Sourcepub const fn iter(&self) -> Iter<PubSubConfigurationRefMask> ⓘ
pub const fn iter(&self) -> Iter<PubSubConfigurationRefMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PubSubConfigurationRefMask> ⓘ
pub const fn iter_names(&self) -> IterNames<PubSubConfigurationRefMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.