pub struct RepublishResponse {
pub response_header: ResponseHeader,
pub notification_message: NotificationMessage,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part4/5.14.6/#5.14.6.2
Fields
response_header: ResponseHeadernotification_message: NotificationMessageTrait Implementations
Sourceimpl BinaryDecodable for RepublishResponse
impl BinaryDecodable for RepublishResponse
Sourcefn decode<S>(
stream: &mut S,
ctx: &Context<'_>,
) -> Result<RepublishResponse, Error>
fn decode<S>( stream: &mut S, ctx: &Context<'_>, ) -> Result<RepublishResponse, Error>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for RepublishResponse
impl BinaryEncodable for RepublishResponse
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
fn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for RepublishResponse
impl Clone for RepublishResponse
Sourcefn clone(&self) -> RepublishResponse
fn clone(&self) -> RepublishResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepublishResponse
impl Debug for RepublishResponse
Sourceimpl Default for RepublishResponse
impl Default for RepublishResponse
Sourcefn default() -> RepublishResponse
fn default() -> RepublishResponse
Returns the “default value” for a type. Read more
Sourceimpl From<RepublishResponse> for ResponseMessage
impl From<RepublishResponse> for ResponseMessage
Sourcefn from(value: RepublishResponse) -> ResponseMessage
fn from(value: RepublishResponse) -> ResponseMessage
Converts to this type from the input type.
Sourceimpl JsonDecodable for RepublishResponse
impl JsonDecodable for RepublishResponse
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<RepublishResponse, Error>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<RepublishResponse, Error>
Decode Self from a JSON stream.
Sourceimpl JsonEncodable for RepublishResponse
impl JsonEncodable for RepublishResponse
Sourceimpl MessageInfo for RepublishResponse
impl MessageInfo for RepublishResponse
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl PartialEq for RepublishResponse
impl PartialEq for RepublishResponse
Sourceimpl UaNullable for RepublishResponse
impl UaNullable for RepublishResponse
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for RepublishResponse
impl XmlDecodable for RepublishResponse
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<RepublishResponse, Error>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<RepublishResponse, Error>
Decode a value from an XML stream.
Sourceimpl XmlEncodable for RepublishResponse
impl XmlEncodable for RepublishResponse
Sourceimpl XmlType for RepublishResponse
impl XmlType for RepublishResponse
impl StructuralPartialEq for RepublishResponse