pub struct ThreeDCartesianCoordinates {
pub x: f64,
pub y: f64,
pub z: f64,
}Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part5/12.26
Fields
x: f64y: f64z: f64Trait Implementations
Sourceimpl BinaryDecodable for ThreeDCartesianCoordinates
impl BinaryDecodable for ThreeDCartesianCoordinates
Sourcefn decode<S>(
stream: &mut S,
ctx: &Context<'_>,
) -> Result<ThreeDCartesianCoordinates, Error>
fn decode<S>( stream: &mut S, ctx: &Context<'_>, ) -> Result<ThreeDCartesianCoordinates, Error>
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a
BadDecodingError as soon as possible.Sourceimpl BinaryEncodable for ThreeDCartesianCoordinates
impl BinaryEncodable for ThreeDCartesianCoordinates
Sourcefn byte_len(&self, ctx: &Context<'_>) -> usize
fn byte_len(&self, ctx: &Context<'_>) -> usize
Returns the exact byte length of the structure as it would be if
encode were called.
This may be called prior to writing to ensure the correct amount of space is available.Sourcefn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
fn encode<S>(&self, stream: &mut S, ctx: &Context<'_>) -> Result<(), Error>
Encodes the instance to the write stream.
Sourcefn override_encoding(&self) -> Option<BuiltInDataEncoding>
fn override_encoding(&self) -> Option<BuiltInDataEncoding>
Override the extension object encoding used for this type.
This only makes sense if the type can only ever be encoded using a single
built-in encoding.
Sourceimpl Clone for ThreeDCartesianCoordinates
impl Clone for ThreeDCartesianCoordinates
Sourcefn clone(&self) -> ThreeDCartesianCoordinates
fn clone(&self) -> ThreeDCartesianCoordinates
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreeDCartesianCoordinates
impl Debug for ThreeDCartesianCoordinates
Sourceimpl Default for ThreeDCartesianCoordinates
impl Default for ThreeDCartesianCoordinates
Sourcefn default() -> ThreeDCartesianCoordinates
fn default() -> ThreeDCartesianCoordinates
Returns the “default value” for a type. Read more
Sourceimpl JsonDecodable for ThreeDCartesianCoordinates
impl JsonDecodable for ThreeDCartesianCoordinates
Sourcefn decode(
stream: &mut JsonStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<ThreeDCartesianCoordinates, Error>
fn decode( stream: &mut JsonStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<ThreeDCartesianCoordinates, Error>
Decode Self from a JSON stream.
Sourceimpl MessageInfo for ThreeDCartesianCoordinates
impl MessageInfo for ThreeDCartesianCoordinates
Sourcefn json_type_id(&self) -> ObjectId
fn json_type_id(&self) -> ObjectId
The JSON type id associated with the message.
Sourcefn xml_type_id(&self) -> ObjectId
fn xml_type_id(&self) -> ObjectId
The XML type id associated with the message.
Sourcefn data_type_id(&self) -> DataTypeId
fn data_type_id(&self) -> DataTypeId
The data type id associated with the message.
Sourceimpl UaNullable for ThreeDCartesianCoordinates
impl UaNullable for ThreeDCartesianCoordinates
Sourcefn is_ua_null(&self) -> bool
fn is_ua_null(&self) -> bool
Return true if this value is null, meaning it can be left out when
being encoded in JSON and XML encodings.
Sourceimpl XmlDecodable for ThreeDCartesianCoordinates
impl XmlDecodable for ThreeDCartesianCoordinates
Sourcefn decode(
stream: &mut XmlStreamReader<&mut dyn Read>,
ctx: &Context<'_>,
) -> Result<ThreeDCartesianCoordinates, Error>
fn decode( stream: &mut XmlStreamReader<&mut dyn Read>, ctx: &Context<'_>, ) -> Result<ThreeDCartesianCoordinates, Error>
Decode a value from an XML stream.
Sourceimpl XmlType for ThreeDCartesianCoordinates
impl XmlType for ThreeDCartesianCoordinates
impl StructuralPartialEq for ThreeDCartesianCoordinates