pub struct UserConfigurationMask(/* private fields */);Expand description
https://reference.opcfoundation.org/v105/Core/docs/Part18/5.2.3
Implementations
Sourceimpl UserConfigurationMask
impl UserConfigurationMask
Sourcepub const NoDelete: UserConfigurationMask
pub const NoDelete: UserConfigurationMask
The user cannot be deleted.
Sourcepub const Disabled: UserConfigurationMask
pub const Disabled: UserConfigurationMask
The user is disabled.
Sourcepub const NoChangeByUser: UserConfigurationMask
pub const NoChangeByUser: UserConfigurationMask
The user cannot change the password.
Sourcepub const MustChangePassword: UserConfigurationMask
pub const MustChangePassword: UserConfigurationMask
The user must change the password to get the assigned roles. If the password is not changed, the user has only the Role Anonymous.
Sourceimpl UserConfigurationMask
impl UserConfigurationMask
Sourcepub const fn empty() -> UserConfigurationMask
pub const fn empty() -> UserConfigurationMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> UserConfigurationMask
pub const fn all() -> UserConfigurationMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<UserConfigurationMask>
pub const fn from_bits(bits: i32) -> Option<UserConfigurationMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> UserConfigurationMask
pub const fn from_bits_truncate(bits: i32) -> UserConfigurationMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> UserConfigurationMask
pub const fn from_bits_retain(bits: i32) -> UserConfigurationMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<UserConfigurationMask>
pub fn from_name(name: &str) -> Option<UserConfigurationMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: UserConfigurationMask) -> bool
pub const fn intersects(&self, other: UserConfigurationMask) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: UserConfigurationMask) -> bool
pub const fn contains(&self, other: UserConfigurationMask) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: UserConfigurationMask)
pub fn insert(&mut self, other: UserConfigurationMask)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: UserConfigurationMask)
pub fn remove(&mut self, other: UserConfigurationMask)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: UserConfigurationMask)
pub fn toggle(&mut self, other: UserConfigurationMask)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: UserConfigurationMask, value: bool)
pub fn set(&mut self, other: UserConfigurationMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: UserConfigurationMask,
) -> UserConfigurationMask
pub const fn intersection( self, other: UserConfigurationMask, ) -> UserConfigurationMask
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: UserConfigurationMask) -> UserConfigurationMask
pub const fn union(self, other: UserConfigurationMask) -> UserConfigurationMask
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: UserConfigurationMask,
) -> UserConfigurationMask
pub const fn difference( self, other: UserConfigurationMask, ) -> UserConfigurationMask
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: UserConfigurationMask,
) -> UserConfigurationMask
pub const fn symmetric_difference( self, other: UserConfigurationMask, ) -> UserConfigurationMask
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> UserConfigurationMask
pub const fn complement(self) -> UserConfigurationMask
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl UserConfigurationMask
impl UserConfigurationMask
Sourcepub const fn iter(&self) -> Iter<UserConfigurationMask> ⓘ
pub const fn iter(&self) -> Iter<UserConfigurationMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<UserConfigurationMask> ⓘ
pub const fn iter_names(&self) -> IterNames<UserConfigurationMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.