pub struct WriteMask(/* private fields */);Expand description
Bitmask for attributes used during write.
Implementations
Sourceimpl WriteMask
impl WriteMask
Sourcepub const ACCESS_LEVEL: WriteMask
pub const ACCESS_LEVEL: WriteMask
Indicates if the AccessLevel Attribute is writable.
Sourcepub const ARRAY_DIMENSIONS: WriteMask
pub const ARRAY_DIMENSIONS: WriteMask
Indicates if the ArrayDimensions Attribute is writable.
Sourcepub const BROWSE_NAME: WriteMask
pub const BROWSE_NAME: WriteMask
Indicates if the BrowseName Attribute is writable.
Sourcepub const CONTAINS_NO_LOOPS: WriteMask
pub const CONTAINS_NO_LOOPS: WriteMask
Indicates if the ContainsNoLoops Attribute is writable.
Sourcepub const DESCRIPTION: WriteMask
pub const DESCRIPTION: WriteMask
Indicates if the Description Attribute is writable.
Sourcepub const DISPLAY_NAME: WriteMask
pub const DISPLAY_NAME: WriteMask
Indicates if the DisplayName Attribute is writable.
Sourcepub const EVENT_NOTIFIER: WriteMask
pub const EVENT_NOTIFIER: WriteMask
Indicates if the EventNotifier Attribute is writable.
Sourcepub const EXECUTABLE: WriteMask
pub const EXECUTABLE: WriteMask
Indicates if the Executable Attribute is writable.
Sourcepub const HISTORIZING: WriteMask
pub const HISTORIZING: WriteMask
Indicates if the Historizing Attribute is writable.
Sourcepub const INVERSE_NAME: WriteMask
pub const INVERSE_NAME: WriteMask
Indicates if the InverseName Attribute is writable.
Sourcepub const IS_ABSTRACT: WriteMask
pub const IS_ABSTRACT: WriteMask
Indicates if the IsAbstract Attribute is writable.
Sourcepub const MINIMUM_SAMPLING_INTERVAL: WriteMask
pub const MINIMUM_SAMPLING_INTERVAL: WriteMask
Indicates if the MinimumSamplingInterval Attribute is writable.
Sourcepub const NODE_CLASS: WriteMask
pub const NODE_CLASS: WriteMask
Indicates if the NodeClass Attribute is writable.
Sourcepub const USER_ACCESS_LEVEL: WriteMask
pub const USER_ACCESS_LEVEL: WriteMask
Indicates if the UserAccessLevel Attribute is writable.
Sourcepub const USER_EXECUTABLE: WriteMask
pub const USER_EXECUTABLE: WriteMask
Indicates if the UserExecutable Attribute is writable.
Sourcepub const USER_WRITE_MASK: WriteMask
pub const USER_WRITE_MASK: WriteMask
Indicates if the UserWriteMask Attribute is writable.
Sourcepub const VALUE_RANK: WriteMask
pub const VALUE_RANK: WriteMask
Indicates if the ValueRank Attribute is writable.
Sourcepub const WRITE_MASK: WriteMask
pub const WRITE_MASK: WriteMask
Indicates if the WriteMask Attribute is writable.
Sourcepub const VALUE_FOR_VARIABLE_TYPE: WriteMask
pub const VALUE_FOR_VARIABLE_TYPE: WriteMask
Indicates if the Value Attribute is writable for a VariableType. It does not apply for Variables since this is handled by the AccessLevel and UserAccessLevel Attributes for the Variable. For Variables this bit shall be set to 0.
Sourcepub const DATA_TYPE_DEFINITION: WriteMask
pub const DATA_TYPE_DEFINITION: WriteMask
Indicates if the DataTypeDefinition Attribute is writable.
Sourcepub const ROLE_PERMISSIONS: WriteMask
pub const ROLE_PERMISSIONS: WriteMask
Indicates if the RolePermissions Attribute is writable.
Sourcepub const ACCESS_RESTRICTIONS: WriteMask
pub const ACCESS_RESTRICTIONS: WriteMask
Indicates if the AccessRestrictions Attribute is writable
Sourcepub const ACCESS_LEVEL_EX: WriteMask
pub const ACCESS_LEVEL_EX: WriteMask
Indicates if the AccessLevelEx Attribute is writable
Sourceimpl WriteMask
impl WriteMask
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<WriteMask>
pub const fn from_bits(bits: u32) -> Option<WriteMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> WriteMask
pub const fn from_bits_truncate(bits: u32) -> WriteMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> WriteMask
pub const fn from_bits_retain(bits: u32) -> WriteMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WriteMask>
pub fn from_name(name: &str) -> Option<WriteMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WriteMask) -> bool
pub const fn intersects(&self, other: WriteMask) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: WriteMask) -> bool
pub const fn contains(&self, other: WriteMask) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: WriteMask)
pub fn remove(&mut self, other: WriteMask)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WriteMask)
pub fn toggle(&mut self, other: WriteMask)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: WriteMask, value: bool)
pub fn set(&mut self, other: WriteMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WriteMask) -> WriteMask
pub const fn intersection(self, other: WriteMask) -> WriteMask
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: WriteMask) -> WriteMask
pub const fn union(self, other: WriteMask) -> WriteMask
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: WriteMask) -> WriteMask
pub const fn difference(self, other: WriteMask) -> WriteMask
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: WriteMask) -> WriteMask
pub const fn symmetric_difference(self, other: WriteMask) -> WriteMask
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> WriteMask
pub const fn complement(self) -> WriteMask
The bitwise negation (!) of the bits in a flags value, truncating the result.