pub struct XmlElement(/* private fields */);Expand description
XML element, represented as a string.
Note that this is deprecated, according to the OPC-UA standard, it is kept in the library for backwards compatibility.
Constructors are not checked, so the contents are not guaranteed to be valid XML, or really XML at all.
Implementations
Sourceimpl XmlElement
impl XmlElement
Sourcepub fn null() -> XmlElement
pub fn null() -> XmlElement
Create a new null XmlElement.