Duration

Type Alias Duration 

pub type Duration = f64;
This Simple DataType is a Double that defines an interval of time in milliseconds (fractions can be used to define sub-millisecond values). Negative values are generally invalid but may have special meanings where the Duration is used. Duration = 290,