pub struct TypeLoaderCollection { /* private fields */ }Expand description
Wrapper type around a vector of type loaders that maintains
sorted order according to the priority of each type loader.
Implementations
Sourceimpl TypeLoaderCollection
impl TypeLoaderCollection
Sourcepub fn new() -> TypeLoaderCollection
pub fn new() -> TypeLoaderCollection
Create a new type loader collection containing only the generated type loader and the fallback type loader.
Sourcepub fn new_empty() -> TypeLoaderCollection
pub fn new_empty() -> TypeLoaderCollection
Create a new type loader collection without any type loaders at all, not even the built-ins. This is usually only useful for testing.
Sourcepub fn add_type_loader(&mut self, loader: impl TypeLoader + 'static)
pub fn add_type_loader(&mut self, loader: impl TypeLoader + 'static)
Add a type loader to the collection.
Sourcepub fn add(&mut self, loader: Arc<dyn TypeLoader>)
pub fn add(&mut self, loader: Arc<dyn TypeLoader>)
Add a type loader to the collection.
Sourcepub fn iter(&self) -> <&TypeLoaderCollection as IntoIterator>::IntoIter
pub fn iter(&self) -> <&TypeLoaderCollection as IntoIterator>::IntoIter
Iterate over the type loaders.