pub struct XmlError {
pub span: Range<usize>,
pub error: XmlErrorInner,
}Expand description
Error returned from loading an XML document.
Fields
span: Range<usize>Where in the document the node that caused the issue is found.
error: XmlErrorInnerThe inner error variant.
Implementations
Sourceimpl XmlError
impl XmlError
Sourcepub fn missing_field(node: &Node<'_, '_>, name: &str) -> XmlError
pub fn missing_field(node: &Node<'_, '_>, name: &str) -> XmlError
Create an error for a node with a missing field with name name.
Sourcepub fn missing_attribute(node: &Node<'_, '_>, name: &str) -> XmlError
pub fn missing_attribute(node: &Node<'_, '_>, name: &str) -> XmlError
Create an error for a node with a missing attribute with name name.
Sourcepub fn other(node: &Node<'_, '_>, info: &str) -> XmlError
pub fn other(node: &Node<'_, '_>, info: &str) -> XmlError
Create an error for some other, general error.
Sourcepub fn parse_int(
node: &Node<'_, '_>,
attr: &str,
err: ParseIntError,
) -> XmlError
pub fn parse_int( node: &Node<'_, '_>, attr: &str, err: ParseIntError, ) -> XmlError
Create an error for failing to parse a string as an integer.
Sourcepub fn parse_float(
node: &Node<'_, '_>,
attr: &str,
err: ParseFloatError,
) -> XmlError
pub fn parse_float( node: &Node<'_, '_>, attr: &str, err: ParseFloatError, ) -> XmlError
Create an error for failing to parse a string as a float.
Sourcepub fn parse_bool(
node: &Node<'_, '_>,
attr: &str,
err: ParseBoolError,
) -> XmlError
pub fn parse_bool( node: &Node<'_, '_>, attr: &str, err: ParseBoolError, ) -> XmlError
Create an error for failing to parse a string as a boolean.
Sourcepub fn parse_date_time(
node: &Node<'_, '_>,
attr: &str,
err: ParseError,
) -> XmlError
pub fn parse_date_time( node: &Node<'_, '_>, attr: &str, err: ParseError, ) -> XmlError
Create an error for failing to parse a string as a date time.
Sourcepub fn parse_uuid(node: &Node<'_, '_>, attr: &str, err: Error) -> XmlError
pub fn parse_uuid(node: &Node<'_, '_>, attr: &str, err: Error) -> XmlError
Create an error for failing to parse a string as a UUID.
Sourcepub fn missing_content(node: &Node<'_, '_>) -> XmlError
pub fn missing_content(node: &Node<'_, '_>) -> XmlError
Create an error indicating that node does not have the necessary content.