#[non_exhaustive]pub enum SessionPollResult {
Transport(TransportPollResult),
ConnectionLost(StatusCode),
ReconnectFailed(StatusCode),
Reconnected(SessionConnectMode),
SessionActivity(SessionActivity),
Subscription(SubscriptionActivity),
BeginConnect,
FinishedDisconnect,
}Expand description
A list of possible events that happens while polling the session. The client can use this list to monitor events such as disconnects, publish failures, etc.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Transport(TransportPollResult)
A message was sent to or received from the server.
ConnectionLost(StatusCode)
Connection was lost with the inner StatusCode.
ReconnectFailed(StatusCode)
Reconnecting to the server failed with the inner StatusCode.
Reconnected(SessionConnectMode)
Session was reconnected, the mode is given by the innner SessionConnectMode
SessionActivity(SessionActivity)
The session performed some periodic activity.
Subscription(SubscriptionActivity)
The session performed some subscription-related activity.
BeginConnect
The session begins (re)connecting to the server.
FinishedDisconnect
Disconnect due to a keep alive terminated.