pub enum SecurityHeader {
Asymmetric(AsymmetricSecurityHeader),
Symmetric(SymmetricSecurityHeader),
}Expand description
Holds the security header associated with the chunk. Secure channel requests use an asymmetric security header, regular messages use a symmetric security header.
Variants
Asymmetric(AsymmetricSecurityHeader)
Security header for asymmetric encryption.
Symmetric(SymmetricSecurityHeader)
Security header for symmetric encryption.
Implementations
Sourceimpl SecurityHeader
impl SecurityHeader
Sourcepub fn decode_from_stream<S>(
stream: &mut S,
is_open_secure_channel: bool,
decoding_options: &DecodingOptions,
) -> Result<SecurityHeader, Error>
pub fn decode_from_stream<S>( stream: &mut S, is_open_secure_channel: bool, decoding_options: &DecodingOptions, ) -> Result<SecurityHeader, Error>
Decode the security header from a stream. The type of header is given by the message header, so this type doesn’t implement BinaryDecodable.