pub fn byte_string(number_of_bytes: usize) -> ByteStringExpand description
Create a byte string with a number of random characters. Can be used to create a nonce or a similar reason.
pub fn byte_string(number_of_bytes: usize) -> ByteStringCreate a byte string with a number of random characters. Can be used to create a nonce or a similar reason.