pub struct DataTypeBuilder { /* private fields */ }Expand description
A builder for constructing a node of same name. This can be used as an easy way to create a node and the references it has to another node in a simple fashion.
Implementations
Sourceimpl DataTypeBuilder
impl DataTypeBuilder
Sourcepub fn new<T, S>(
node_id: &NodeId,
browse_name: T,
display_name: S,
) -> DataTypeBuilder
pub fn new<T, S>( node_id: &NodeId, browse_name: T, display_name: S, ) -> DataTypeBuilder
Creates a builder for a node. All nodes are required to su
Sourcepub fn get_node_id(&self) -> &NodeId
pub fn get_node_id(&self) -> &NodeId
Get the node ID of the node being built.
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Tests that the builder is in a valid state to build or insert the node.
Sourcepub fn description<V>(self, description: V) -> DataTypeBuilderwhere
V: Into<LocalizedText>,
pub fn description<V>(self, description: V) -> DataTypeBuilderwhere
V: Into<LocalizedText>,
Sets the description of the node
Sourcepub fn reference<T>(
self,
node_id: T,
reference_type_id: ReferenceTypeId,
reference_direction: ReferenceDirection,
) -> DataTypeBuilder
pub fn reference<T>( self, node_id: T, reference_type_id: ReferenceTypeId, reference_direction: ReferenceDirection, ) -> DataTypeBuilder
Adds a reference to the node
Sourcepub fn organizes<T>(self, organizes_id: T) -> DataTypeBuilder
pub fn organizes<T>(self, organizes_id: T) -> DataTypeBuilder
Indicates this node organizes another node by its id.
Sourcepub fn organized_by<T>(self, organized_by_id: T) -> DataTypeBuilder
pub fn organized_by<T>(self, organized_by_id: T) -> DataTypeBuilder
Indicates this node is organised by another node by its id
Sourcepub fn build(self) -> DataType
pub fn build(self) -> DataType
Yields a built node. This function will panic if the node is invalid. Note that calling this function discards any references for the node, so there is no purpose in adding references if you intend to call this method.
Sourcepub fn insert(self, address_space: &mut impl NodeInsertTarget) -> bool
pub fn insert(self, address_space: &mut impl NodeInsertTarget) -> bool
Inserts the node into the address space, including references. This function will panic if the node is in an invalid state.
Sourceimpl DataTypeBuilder
impl DataTypeBuilder
Sourcepub fn subtype_of<T>(self, type_id: T) -> DataTypeBuilder
pub fn subtype_of<T>(self, type_id: T) -> DataTypeBuilder
Add an inverse HasSubtype reference to the given
type.
Sourcepub fn has_subtype<T>(self, subtype_id: T) -> DataTypeBuilder
pub fn has_subtype<T>(self, subtype_id: T) -> DataTypeBuilder
Add a HasSubtype reference to the given type.
Sourceimpl DataTypeBuilder
impl DataTypeBuilder
Sourcepub fn is_abstract(self, is_abstract: bool) -> DataTypeBuilder
pub fn is_abstract(self, is_abstract: bool) -> DataTypeBuilder
Set whether the data type is abstract, meaning it cannot be used by nodes in the instance hierarchy.
Sourcepub fn write_mask(self, write_mask: WriteMask) -> DataTypeBuilder
pub fn write_mask(self, write_mask: WriteMask) -> DataTypeBuilder
Set the data type write mask.
Sourcepub fn data_type_definition(
self,
data_type_definition: DataTypeDefinition,
) -> DataTypeBuilder
pub fn data_type_definition( self, data_type_definition: DataTypeDefinition, ) -> DataTypeBuilder
Set the data type definition.