pub struct ViewBuilder { /* private fields */ }Expand description
A builder for constructing a node of same name. This can be used as an easy way to create a node and the references it has to another node in a simple fashion.
Implementations
Sourceimpl ViewBuilder
impl ViewBuilder
Sourcepub fn new<T, S>(
node_id: &NodeId,
browse_name: T,
display_name: S,
) -> ViewBuilder
pub fn new<T, S>( node_id: &NodeId, browse_name: T, display_name: S, ) -> ViewBuilder
Creates a builder for a node. All nodes are required to su
Sourcepub fn get_node_id(&self) -> &NodeId
pub fn get_node_id(&self) -> &NodeId
Get the node ID of the node being built.
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Tests that the builder is in a valid state to build or insert the node.
Sourcepub fn description<V>(self, description: V) -> ViewBuilderwhere
V: Into<LocalizedText>,
pub fn description<V>(self, description: V) -> ViewBuilderwhere
V: Into<LocalizedText>,
Sets the description of the node
Sourcepub fn reference<T>(
self,
node_id: T,
reference_type_id: ReferenceTypeId,
reference_direction: ReferenceDirection,
) -> ViewBuilder
pub fn reference<T>( self, node_id: T, reference_type_id: ReferenceTypeId, reference_direction: ReferenceDirection, ) -> ViewBuilder
Adds a reference to the node
Sourcepub fn organizes<T>(self, organizes_id: T) -> ViewBuilder
pub fn organizes<T>(self, organizes_id: T) -> ViewBuilder
Indicates this node organizes another node by its id.
Sourcepub fn organized_by<T>(self, organized_by_id: T) -> ViewBuilder
pub fn organized_by<T>(self, organized_by_id: T) -> ViewBuilder
Indicates this node is organised by another node by its id
Sourcepub fn build(self) -> View
pub fn build(self) -> View
Yields a built node. This function will panic if the node is invalid. Note that calling this function discards any references for the node, so there is no purpose in adding references if you intend to call this method.
Sourcepub fn insert(self, address_space: &mut impl NodeInsertTarget) -> bool
pub fn insert(self, address_space: &mut impl NodeInsertTarget) -> bool
Inserts the node into the address space, including references. This function will panic if the node is in an invalid state.
Sourceimpl ViewBuilder
impl ViewBuilder
Sourcepub fn generates_event<T>(self, event_type: T) -> ViewBuilder
pub fn generates_event<T>(self, event_type: T) -> ViewBuilder
Add a GeneratesEvent reference to the given event type.
Sourceimpl ViewBuilder
impl ViewBuilder
Sourcepub fn contains_no_loops(self, contains_no_loops: bool) -> ViewBuilder
pub fn contains_no_loops(self, contains_no_loops: bool) -> ViewBuilder
Set whether the view contains no loops.
Sourcepub fn event_notifier(self, event_notifier: EventNotifier) -> ViewBuilder
pub fn event_notifier(self, event_notifier: EventNotifier) -> ViewBuilder
Set view event notifier.
Sourcepub fn write_mask(self, write_mask: WriteMask) -> ViewBuilder
pub fn write_mask(self, write_mask: WriteMask) -> ViewBuilder
Set view write mask.