pub trait NodeBase {
// Required methods
fn node_class(&self) -> NodeClass;
fn node_id(&self) -> &NodeId;
fn browse_name(&self) -> &QualifiedName;
fn display_name(&self) -> &LocalizedText;
fn set_display_name(&mut self, display_name: LocalizedText);
fn description(&self) -> Option<&LocalizedText>;
fn set_description(&mut self, description: LocalizedText);
fn write_mask(&self) -> Option<WriteMask>;
fn set_write_mask(&mut self, write_mask: WriteMask);
fn user_write_mask(&self) -> Option<WriteMask>;
fn set_user_write_mask(&mut self, write_mask: WriteMask);
}Expand description
Implemented within a macro for all Node types. Functions that return a result in an Option do so because the attribute is optional and not necessarily there.
Required Methods
Sourcefn node_class(&self) -> NodeClass
fn node_class(&self) -> NodeClass
Returns the node class - Object, ObjectType, Method, DataType, ReferenceType, Variable, VariableType or View
Sourcefn browse_name(&self) -> &QualifiedName
fn browse_name(&self) -> &QualifiedName
Returns the node’s browse name
Sourcefn display_name(&self) -> &LocalizedText
fn display_name(&self) -> &LocalizedText
Returns the node’s display name
Sourcefn set_display_name(&mut self, display_name: LocalizedText)
fn set_display_name(&mut self, display_name: LocalizedText)
Sets the node’s display name
Sourcefn description(&self) -> Option<&LocalizedText>
fn description(&self) -> Option<&LocalizedText>
Get the description of this node.
Sourcefn set_description(&mut self, description: LocalizedText)
fn set_description(&mut self, description: LocalizedText)
Set the description of this node.
Sourcefn write_mask(&self) -> Option<WriteMask>
fn write_mask(&self) -> Option<WriteMask>
Get the write mask of this node.
Sourcefn set_write_mask(&mut self, write_mask: WriteMask)
fn set_write_mask(&mut self, write_mask: WriteMask)
Set the write mask of this node.
Sourcefn user_write_mask(&self) -> Option<WriteMask>
fn user_write_mask(&self) -> Option<WriteMask>
Get the user write mask for this node.
Sourcefn set_user_write_mask(&mut self, write_mask: WriteMask)
fn set_user_write_mask(&mut self, write_mask: WriteMask)
Set the user write mask for this node.