pub trait NodeSetImport {
// Required methods
fn register_namespaces(&self, namespaces: &mut NodeSetNamespaceMapper<'_>);
fn get_own_namespaces(&self) -> Vec<String>;
fn load<'a>(
&'a self,
namespaces: &'a NodeSetNamespaceMapper<'_>,
) -> Box<dyn Iterator<Item = ImportedItem> + 'a>;
}Expand description
Trait for a type that wraps a nodeset import.
Currently this is implemeneted by the crate::xml::NodeSet2Import type
with the xml feature, and by a type in the root of node set imports generated by
async-opcua-codegen
Required Methods
Sourcefn register_namespaces(&self, namespaces: &mut NodeSetNamespaceMapper<'_>)
fn register_namespaces(&self, namespaces: &mut NodeSetNamespaceMapper<'_>)
Register all namespaces used by this importer in a node set map.
Sourcefn get_own_namespaces(&self) -> Vec<String>
fn get_own_namespaces(&self) -> Vec<String>
Get a list of namespaces that this import owns. This must be a subset of the
namespaces it uses, registered in register_namespaces
Sourcefn load<'a>(
&'a self,
namespaces: &'a NodeSetNamespaceMapper<'_>,
) -> Box<dyn Iterator<Item = ImportedItem> + 'a>
fn load<'a>( &'a self, namespaces: &'a NodeSetNamespaceMapper<'_>, ) -> Box<dyn Iterator<Item = ImportedItem> + 'a>
Create an iterator over items imported from the nodeset. This will usually be lazy.