pub struct DefaultAuthenticator { /* private fields */ }Expand description
A simple authenticator that keeps a map of valid users in memory. In production applications you will almost always want to create your own custom authenticator.
Implementations
Sourceimpl DefaultAuthenticator
impl DefaultAuthenticator
Sourcepub fn new(users: BTreeMap<String, ServerUserToken>) -> DefaultAuthenticator
pub fn new(users: BTreeMap<String, ServerUserToken>) -> DefaultAuthenticator
Create a new default authenticator with the given set of users.