pub struct LocalValue<T> { /* private fields */ }Expand description
Wrapper around a value in memory, used for metrics. We need to use a mutex to keep track of when the value was last updated.
Implementations
Sourceimpl<T> LocalValue<T>where
T: Clone + IntoVariant,
impl<T> LocalValue<T>where
T: Clone + IntoVariant,
Sourcepub fn new(value: T) -> LocalValue<T>
pub fn new(value: T) -> LocalValue<T>
Create a new LocalValue with the given value.
Sourcepub fn get_with_time(&self) -> (T, DateTime)
pub fn get_with_time(&self) -> (T, DateTime)
Get the current value and timestamp.