pub struct ServerDiagnostics {
pub summary: ServerDiagnosticsSummary,
pub enabled: bool,
}Expand description
The server diagnostics struct, containing shared types for various forms of server diagnostics.
Fields
summary: ServerDiagnosticsSummaryServer diagnostics summary.
enabled: boolWhether diagnostics are enabled or not. Set on server startup.
Implementations
Sourceimpl ServerDiagnostics
impl ServerDiagnostics
Sourcepub fn is_mapped(&self, variable_id: VariableId) -> bool
pub fn is_mapped(&self, variable_id: VariableId) -> bool
Check if the given variable ID is managed by this object.
Sourcepub fn get(&self, variable_id: VariableId) -> Option<DataValue>
pub fn get(&self, variable_id: VariableId) -> Option<DataValue>
Get the value of a diagnostics element by its ID.
Sourcepub fn set_current_session_count(&self, count: u32)
pub fn set_current_session_count(&self, count: u32)
Set the current session count.
Sourcepub fn set_current_subscription_count(&self, count: u32)
pub fn set_current_subscription_count(&self, count: u32)
Set the current subscription count.
Sourcepub fn inc_session_count(&self)
pub fn inc_session_count(&self)
Increment the cumulated session count.
Sourcepub fn inc_subscription_count(&self)
pub fn inc_subscription_count(&self)
Increment the cumulated subscription count.
Sourcepub fn inc_rejected_requests(&self)
pub fn inc_rejected_requests(&self)
Increment the rejected requests count.
Sourcepub fn inc_security_rejected_requests(&self)
pub fn inc_security_rejected_requests(&self)
Increment the security rejected requests count.
Sourcepub fn inc_security_rejected_session_count(&self)
pub fn inc_security_rejected_session_count(&self)
Increment the security rejected session count.
Sourcepub fn set_server_view_count(&self, count: u32)
pub fn set_server_view_count(&self, count: u32)
Set the number of server-created views.
Sourcepub fn inc_session_abort_count(&self)
pub fn inc_session_abort_count(&self)
Increment the session abort count.
Sourcepub fn inc_session_timeout_count(&self)
pub fn inc_session_timeout_count(&self)
Increment the session timeout count.
Sourcepub fn set_publishing_interval_count(&self, count: u32)
pub fn set_publishing_interval_count(&self, count: u32)
Set the number of publishing intervals supported by the server.