macro_rules! load_method_args {
($call:expr, $($type:ident),+) => { ... };
}Expand description
Convenient macro for performing an implicit cast of each argument to the expected method argument type, and returning the arguments as a tuple.
This macro will produce Result<(Arg1, Arg2, ...), StatusCode>.
The types in the argument list must be enum variants of the Variant type.
Example
ⓘ
let (arg1, arg2) = load_method_args!(method_call, Int32, String)?;