The implementation of InMemoryNodeManager, a generic node manager that keeps all its nodes in memory, and delegates implementing details to a type implementing InMemoryNodeManagerImpl.
Structs
- Core
Node Manager Builder - Builder for the CoreNodeManager.
- Core
Node Manager Impl - Node manager impl for the core namespace.
- InMemory
Node Manager - A node manager that stores its nodes in an in-memory AddressSpace. This only supports a static list of namespaces, and a attributes stored in memory.
- InMemory
Node Manager Builder - Builder for the in-memory node manager.
- Simple
Node Manager Builder - Builder for the SimpleNodeManager.
- Simple
Node Manager Impl - Node manager designed to deal with simple, entirely in-memory, synchronous OPC-UA servers.
Traits
- InMemory
Node Manager Impl - Trait for user-provided implementation of the InMemoryNodeManager
- InMemory
Node Manager Impl Builder - Trait for constructing an InMemoryNodeManagerImpl.
Functions
- simple_
node_ manager - Create a node manager builder for the simple node manager with the given namespace and name.
- simple_
node_ manager_ imports - Create a new simple node manager that imports from the given list of NodeSetImports.
Type Aliases
- Core
Node Manager - Node manager for the core namespace.
- Simple
Node Manager - A simple in-memory node manager with utility methods for updating the address space,
and a mechanism for setting callbacks on
ReadandWriteof values.