pub trait InMemoryNodeManagerImplBuilder {
type Impl: InMemoryNodeManagerImpl;
// Required method
fn build(
self,
context: ServerContext,
address_space: &mut AddressSpace,
) -> Self::Impl;
}Expand description
Trait for constructing an InMemoryNodeManagerImpl.
Note that this is called with the lock on the AddressSpace held, if you try to lock it again, it will deadlock.
Required Associated Types
Sourcetype Impl: InMemoryNodeManagerImpl
type Impl: InMemoryNodeManagerImpl
Type implementing InMemoryNodeManagerImpl constructed by this builder.
Required Methods
Sourcefn build(
self,
context: ServerContext,
address_space: &mut AddressSpace,
) -> Self::Impl
fn build( self, context: ServerContext, address_space: &mut AddressSpace, ) -> Self::Impl
Build the node manager impl.