pub struct HistoryUpdateNode { /* private fields */ }Expand description
History update details for one node.
Implementations
Sourceimpl HistoryUpdateNode
impl HistoryUpdateNode
Sourcepub fn set_status(&mut self, status: StatusCode)
pub fn set_status(&mut self, status: StatusCode)
Set the result status of this history operation.
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the current status.
Sourcepub fn set_operation_results(
&mut self,
operation_results: Option<Vec<StatusCode>>,
)
pub fn set_operation_results( &mut self, operation_results: Option<Vec<StatusCode>>, )
Set the operation results. If present the length must match the length of the entries in the history update details.
Sourcepub fn details(&self) -> &HistoryUpdateDetails
pub fn details(&self) -> &HistoryUpdateDetails
Get a reference to the history update details describing the history update to execute.