pub struct ReadNode { /* private fields */ }Expand description
Container for a single item in a Read service call.
Implementations
Sourceimpl ReadNode
impl ReadNode
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the current result status code.
Sourcepub fn node(&self) -> &ParsedReadValueId
pub fn node(&self) -> &ParsedReadValueId
Get the node/attribute pair to read.
Sourcepub fn set_result(&mut self, result: DataValue)
pub fn set_result(&mut self, result: DataValue)
Set the result of this read operation.
Sourcepub fn set_error(&mut self, status: StatusCode)
pub fn set_error(&mut self, status: StatusCode)
Set the result of this read operation to an error with no value or timestamp. Use this not if the value is an error, but if the read failed.
Sourcepub fn diagnostic_bits(&self) -> DiagnosticBits
pub fn diagnostic_bits(&self) -> DiagnosticBits
Header diagnostic bits for requesting operation-level diagnostics.
Sourcepub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)
pub fn set_diagnostic_info(&mut self, diagnostic_info: DiagnosticInfo)
Set diagnostic infos, you don’t need to do this if
diagnostic_bits are not set.