pub struct RequestContextInner {
pub session: Arc<RwLock<RawRwLock, Session>>,
pub session_id: u32,
pub authenticator: Arc<dyn AuthManager>,
pub token: UserToken,
pub type_tree: Arc<RwLock<RawRwLock, DefaultTypeTree>>,
pub type_tree_getter: Arc<dyn TypeTreeForUser>,
pub subscriptions: Arc<SubscriptionCache>,
pub info: Arc<ServerInfo>,
}Expand description
Inner request context object, shared between service calls.
Fields
session: Arc<RwLock<RawRwLock, Session>>The full session object for the session responsible for this service call.
session_id: u32The session ID for the session responsible for this service call.
authenticator: Arc<dyn AuthManager>The global AuthManager object.
token: UserTokenThe current user token.
type_tree: Arc<RwLock<RawRwLock, DefaultTypeTree>>Global type tree object.
type_tree_getter: Arc<dyn TypeTreeForUser>Wrapper to get a type tree
subscriptions: Arc<SubscriptionCache>Subscription cache, containing all subscriptions on the server.
info: Arc<ServerInfo>Server info object, containing configuration and other shared server state.