pub trait TypeTreeForUserStatic: Send + Sync {
// Required method
fn get_type_tree<'a>(&'a self) -> Box<dyn TypeTreeReadContext + 'a>;
}Expand description
Trait for providing a static reference to the type tree for a specific user. This allows subscriptions to hold a reference to the type tree.
Required Methods
Sourcefn get_type_tree<'a>(&'a self) -> Box<dyn TypeTreeReadContext + 'a>
fn get_type_tree<'a>(&'a self) -> Box<dyn TypeTreeReadContext + 'a>
Get the type tree read context. This may lock.