pub struct SubscriptionDataNotifier<'a> { /* private fields */ }Expand description
Handle for notifying the subscription cache of a batch of changes, without allocating NodeIds unnecessarily. Notifications are actually submitted once the notifier is dropped.
Implementations
Sourceimpl<'a> SubscriptionDataNotifier<'a>
impl<'a> SubscriptionDataNotifier<'a>
Sourcepub fn notify_for<'b, 'c>(
&'b mut self,
node_id: impl IntoNodeIdRef<'c>,
attribute_id: AttributeId,
) -> Option<SubscriptionDataNotifierBatch<'b>>
pub fn notify_for<'b, 'c>( &'b mut self, node_id: impl IntoNodeIdRef<'c>, attribute_id: AttributeId, ) -> Option<SubscriptionDataNotifierBatch<'b>>
Sourcepub fn notify(
&mut self,
node_id: impl IntoNodeIdRef<'a>,
attribute_id: AttributeId,
value: impl Into<DataValue>,
)
pub fn notify( &mut self, node_id: impl IntoNodeIdRef<'a>, attribute_id: AttributeId, value: impl Into<DataValue>, )
Notify the subscription cache of a change in value for the given node ID and attribute ID.
Arguments
node_id- The node ID or reference to node ID for the changed node.attribute_id- The attribute ID of the changed value. Note that this may not be EventNotifier.value- The new value as a DataValue or something convertible to a DataValue.