pub struct SubscriptionEventNotifier<'a, 'b> { /* private fields */ }Expand description
Handle for notifying the subscription cache of a batch of events, without allocating NodeIds unnecessarily. Notifications are actually submitted once the notifier is dropped.
Implementations
Sourceimpl<'a, 'b> SubscriptionEventNotifier<'a, 'b>
impl<'a, 'b> SubscriptionEventNotifier<'a, 'b>
Sourcepub fn notify_for<'c>(
&'c mut self,
node_id: impl IntoNodeIdRef<'a>,
) -> Option<SubscriptionEventNotifierBatch<'c, 'b>>
pub fn notify_for<'c>( &'c mut self, node_id: impl IntoNodeIdRef<'a>, ) -> Option<SubscriptionEventNotifierBatch<'c, 'b>>
Sourcepub fn notify(&mut self, node_id: impl IntoNodeIdRef<'a>, event: &'b dyn Event)
pub fn notify(&mut self, node_id: impl IntoNodeIdRef<'a>, event: &'b dyn Event)
Notify the subscription cache of a new event for the given node ID and attribute ID.
Arguments
node_id- The node ID or reference to node ID for the node emitting the event.event- The event to notify the server of.