ContinuationPoint

Struct ContinuationPoint 

pub struct ContinuationPoint { /* private fields */ }
Representation of a dynamic continuation point. Each node manager may provide their own continuation point type, which is stored by the server. This wraps that value and provides interfaces to access it for a given node manager.

Implementations

Source

impl ContinuationPoint

pub fn new<T>(item: Box<T>) -> ContinuationPoint
where T: Send + Sync + 'static,

Create a new continuation point with item as content.

pub fn get<T>(&self) -> Option<&T>
where T: Send + Sync + 'static,

Retrieve the value of the continuation point. This will return None if the stored value is not equal to the given type. Most node managers should report an error if this happens.

pub fn get_mut<T>(&mut self) -> Option<&mut T>
where T: Send + Sync + 'static,

Retrieve the value of the continuation point. This will return None if the stored value is not equal to the given type. Most node managers should report an error if this happens.

pub fn take<T>(self) -> Option<Box<T>>
where T: Send + Sync + 'static,

Consume this continuation point and return a specific type.