pub trait EventField {
// Required method
fn get_value(
&self,
attribute_id: AttributeId,
index_range: &NumericRange,
remaining_path: &[QualifiedName],
) -> Variant;
}Expand description
Trait implemented by any type that can be a field in an event.
Required Methods
Sourcefn get_value(
&self,
attribute_id: AttributeId,
index_range: &NumericRange,
remaining_path: &[QualifiedName],
) -> Variant
fn get_value( &self, attribute_id: AttributeId, index_range: &NumericRange, remaining_path: &[QualifiedName], ) -> Variant
Get the variant representation of this field, using the given index range.
Arguments
attribute_id- the attribute to get. Should be eitherNodeIdorValue.index_range- the range of the value to get.remaining_path- the remaining path to the actual value to retrieve.