Contains the BinaryEncodable trait and helpers for reading and writing of scalar values and
other primitives.
Macros
- impl_
encoded_ as - Implement the encodable traits for a type, using the provided functions to convert to and from some other type.
Structs
- Decoding
Options - General decoding options.
- Depth
Gauge - Depth gauge is used on potentially recursive structures like Variant & ExtensionObject during decoding to limit the depth the decoder will go before giving up.
- Depth
Lock - Depth lock holds a reference on the depth gauge. The drop ensures impl that the reference is decremented even if there is a panic unwind.
- Error
- General OPC-UA error.
Enums
- Built
InData Encoding - Parsed data encoding, only built-in encodings.
- Data
Encoding - Parsed data encoding.
Traits
- Binary
Decodable - Trait for decoding a type from OPC UA binary.
- Binary
Encodable - OPC UA Binary Encoding interface. Anything that encodes to binary must implement this. It provides functions to calculate the size in bytes of the struct (for allocating memory), encoding to a stream and decoding from a stream.
- Simple
Binary Decodable - Trait for decoding a type that cannot contain any custom types from OPC UA binary. Used in some core modules to decode raw binary messages.
- Simple
Binary Encodable - Trait for encoding a type that cannot contain any custom types to OPC UA binary. Used in some core modules to encode raw binary messages.
- UaNullable
- Trait implemented by OPC-UA types, indicating whether they are null or not, for use in encoding.
Functions
- byte_
len_ array - Calculates the length in bytes of an array of encoded type
- process_
decode_ io_ result - Converts an IO encoding error (and logs when in error) into an EncodingResult
- process_
encode_ io_ result - Converts an IO encoding error (and logs when in error) into an EncodingResult
- read_
bytes - Reads an array of bytes from the stream
- read_
f32 - Read a 32-bit precision value from the stream
- read_
f64 - Read a 64-bit precision from the stream
- read_
i16 - Read an signed 16-bit value from the stream
- read_
i32 - Read a signed 32-bit value from the stream
- read_
i64 - Read a signed 64-bit value from the stream
- read_u8
- Read an unsigned byte from the stream
- read_
u16 - Read an unsigned 16-bit value from the stream
- read_
u32 - Read an unsigned 32-bit value from the stream
- read_
u64 - Read an unsigned 64-bit value from the stream
- skip_
bytes - Skip
bytesbytes in the stream. - write_
bytes - Writes a series of identical bytes to the stream
- write_
f32 - Writes a 32-bit precision value to the stream
- write_
f64 - Writes a 64-bit precision value to the stream
- write_
i16 - Writes a signed 16-bit value to the stream
- write_
i32 - Writes a signed 32-bit value to the stream
- write_
i64 - Writes a signed 64-bit value to the stream
- write_
u8 - Writes an unsigned byte to the stream
- write_
u16 - Writes an unsigned 16-bit value to the stream
- write_
u32 - Writes an unsigned 32-bit value to the stream
- write_
u64 - Writes an unsigned 64-bit value to the stream
Type Aliases
- Encoding
Result - Result of an encoding or decoding operation.