Contains implementation of the OPC-UA NodeId type,
which is used to identify nodes in the address space of an OPC-UA server.
Structs
- NodeId
- An identifier for a node in the address space of an OPC UA Server.
- Node
IdError - Error returned from working with node IDs.
- Node
IdRef - Cheap reference to a node ID of a specific type.
Enums
- Identifier
- The kind of identifier, numeric, string, guid or byte
Constants
- IDENTIFIER_
HASH_ BYTE_ STRING - Value used as discriminator when hashing byte string node IDs.
- IDENTIFIER_
HASH_ GUID - Value used as discriminator when hashing Guid node IDs.
- IDENTIFIER_
HASH_ NUMERIC - Value used as discriminator when hashing numeric node IDs.
- IDENTIFIER_
HASH_ STRING - Value used as discriminator when hashing string node IDs.
Traits
- Identifier
Ref - Trait that indicates that a type can be used as a reference to an identifier. Contains a special hash method that includes the descriminator for the identifier variant, which means that it hashes to the same value as the equivalent identifier.
- Into
Node IdRef - Trait that allows converting a type into a
NodeIdRef. This is used instead ofIntoto allow for simple function signatures.