Implementation of OPC UA status codes.
See OPC-UA Part 4, part 7.34.1
Structs
- Status
Code - Wrapper around an OPC-UA status code, with utilities for displaying, parsing, and reading.
Enums
- Status
Code Info Type - Whether the status code represents a data value or something else.
- Status
Code Limit - Limit bits on a status code.
- Status
Code Severity - Severity of a status code.
- Status
Code Validation Error - Error returned on status code validation failure.
- Status
Code Value Type - The type of data value
- SubStatus
Code - The category of a status code.