pub struct DateTime { /* private fields */ }Expand description
A date/time value. This is a wrapper around the chrono type with extra functionality for obtaining ticks in OPC UA measurements, endtimes, epoch etc.
Implementations
Sourceimpl DateTime
impl DateTime
Sourcepub fn now_with_offset(offset: TimeDelta) -> DateTime
pub fn now_with_offset(offset: TimeDelta) -> DateTime
Constructs from the current time with an offset
Sourcepub fn endtimes_ticks() -> i64
pub fn endtimes_ticks() -> i64
Returns the maximum tick value, corresponding to the end of time
Sourcepub fn ymd_hms(
year: u16,
month: u16,
day: u16,
hour: u16,
minute: u16,
second: u16,
) -> DateTime
pub fn ymd_hms( year: u16, month: u16, day: u16, hour: u16, minute: u16, second: u16, ) -> DateTime
Constructs from a year, month, day, hour, minute, second
Sourcepub fn ymd_hms_nano(
year: u16,
month: u16,
day: u16,
hour: u16,
minute: u16,
second: u16,
nanos: u32,
) -> DateTime
pub fn ymd_hms_nano( year: u16, month: u16, day: u16, hour: u16, minute: u16, second: u16, nanos: u32, ) -> DateTime
Constructs from a year, month, day, hour, minute, second, nanosecond
Sourcepub fn to_rfc3339(&self) -> String
pub fn to_rfc3339(&self) -> String
Returns an RFC 3339 and ISO 8601 date and time string such as 1996-12-19T16:39:57-08:00.
Sourcepub fn parse_from_rfc3339(s: &str) -> Result<DateTime, ParseError>
pub fn parse_from_rfc3339(s: &str) -> Result<DateTime, ParseError>
Parses an RFC 3339 and ISO 8601 date and time string such as 1996-12-19T16:39:57-08:00, then returns a new DateTime
Sourcepub fn checked_ticks(&self) -> i64
pub fn checked_ticks(&self) -> i64
To checked ticks. Function returns 0 or MAX_INT64 if date exceeds valid OPC UA range