WriteMask

Struct WriteMask 

pub struct WriteMask(/* private fields */);
Bitmask for attributes used during write.

Implementations

Source

impl WriteMask

pub const ACCESS_LEVEL: WriteMask

Indicates if the AccessLevel Attribute is writable.

pub const ARRAY_DIMENSIONS: WriteMask

Indicates if the ArrayDimensions Attribute is writable.

pub const BROWSE_NAME: WriteMask

Indicates if the BrowseName Attribute is writable.

pub const CONTAINS_NO_LOOPS: WriteMask

Indicates if the ContainsNoLoops Attribute is writable.

pub const DATA_TYPE: WriteMask

Indicates if the DataType Attribute is writable.

pub const DESCRIPTION: WriteMask

Indicates if the Description Attribute is writable.

pub const DISPLAY_NAME: WriteMask

Indicates if the DisplayName Attribute is writable.

pub const EVENT_NOTIFIER: WriteMask

Indicates if the EventNotifier Attribute is writable.

pub const EXECUTABLE: WriteMask

Indicates if the Executable Attribute is writable.

pub const HISTORIZING: WriteMask

Indicates if the Historizing Attribute is writable.

pub const INVERSE_NAME: WriteMask

Indicates if the InverseName Attribute is writable.

pub const IS_ABSTRACT: WriteMask

Indicates if the IsAbstract Attribute is writable.

pub const MINIMUM_SAMPLING_INTERVAL: WriteMask

Indicates if the MinimumSamplingInterval Attribute is writable.

pub const NODE_CLASS: WriteMask

Indicates if the NodeClass Attribute is writable.

pub const NODE_ID: WriteMask

Indicates if the NodeId Attribute is writable.

pub const SYMMETRIC: WriteMask

Indicates if the Symmetric Attribute is writable.

pub const USER_ACCESS_LEVEL: WriteMask

Indicates if the UserAccessLevel Attribute is writable.

pub const USER_EXECUTABLE: WriteMask

Indicates if the UserExecutable Attribute is writable.

pub const USER_WRITE_MASK: WriteMask

Indicates if the UserWriteMask Attribute is writable.

pub const VALUE_RANK: WriteMask

Indicates if the ValueRank Attribute is writable.

pub const WRITE_MASK: WriteMask

Indicates if the WriteMask Attribute is writable.

pub const VALUE_FOR_VARIABLE_TYPE: WriteMask

Indicates if the Value Attribute is writable for a VariableType. It does not apply for Variables since this is handled by the AccessLevel and UserAccessLevel Attributes for the Variable. For Variables this bit shall be set to 0.

pub const DATA_TYPE_DEFINITION: WriteMask

Indicates if the DataTypeDefinition Attribute is writable.

pub const ROLE_PERMISSIONS: WriteMask

Indicates if the RolePermissions Attribute is writable.

pub const ACCESS_RESTRICTIONS: WriteMask

Indicates if the AccessRestrictions Attribute is writable

pub const ACCESS_LEVEL_EX: WriteMask

Indicates if the AccessLevelEx Attribute is writable

Source

impl WriteMask

pub const fn empty() -> WriteMask

Get a flags value with all bits unset.

pub const fn all() -> WriteMask

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<WriteMask>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> WriteMask

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> WriteMask

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<WriteMask>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: WriteMask) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: WriteMask) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: WriteMask)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: WriteMask)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: WriteMask)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: WriteMask, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: WriteMask) -> WriteMask

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: WriteMask) -> WriteMask

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: WriteMask) -> WriteMask

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: WriteMask) -> WriteMask

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> WriteMask

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl WriteMask

pub const fn iter(&self) -> Iter<WriteMask>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<WriteMask>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.